@@ -47,7 +47,7 @@ int main( int /*argc*/, char ** argv)
     string textColor = "red";
 
     // Font to use for text
-    string textFont = string("@") + srcdir + "Generic.ttf";
+    string textFont = srcdir + "Generic.ttf";
 
     // Font point size
     int textFontPointSize = 16;
@@ -83,19 +83,15 @@ int main( int /*argc*/, char ** argv)
     button.quantize();
 
     // Save to file
-    cout << "Writing to button.miff" << endl;
-    button.write("button.miff");
+    cout << "Writing to \"button_out.miff\" ..." << endl;
+    button.compressType( RunlengthEncodedCompression );
+    button.write("button_out.miff");
 
     // Display on screen
     // button.display();
 
   }
-  catch( Exception error_ )
-    {
-      cout << "Caught exception: " << error_.what() << endl;
-      return 1;
-    }
-  catch( exception error_ )
+  catch( exception &error_ )
     {
       cout << "Caught exception: " << error_.what() << endl;
       return 1;
