@@ -27,7 +27,7 @@ int main( int /*argc*/, char ** argv)
     srcdir = getenv("srcdir") + string("/");
 
   // Common font to use.
-  string font = string("@") + srcdir + "Generic.ttf";
+  string font = srcdir + "Generic.ttf";
 
   try {
 
@@ -58,15 +58,15 @@ int main( int /*argc*/, char ** argv)
     //
     image.strokeColor( "black" );
     image.fillColor( "red" );
-    image.lineWidth( 5 );
+    image.strokeWidth( 5 );
     image.draw( DrawableEllipse( 100,100, 50,75, 0,360 ) );
     image.fillColor( Color() ); // Clear out fill color
 
     //
-    // Draw ellipse, and polygon, with black stroke, linewidth of 5
+    // Draw ellipse, and polygon, with black stroke, strokeWidth of 5
     //
     image.strokeColor( "black" );
-    image.lineWidth( 5 );
+    image.strokeWidth( 5 );
     list<Drawable> drawlist;
 
     // Add polygon to list
@@ -87,42 +87,35 @@ int main( int /*argc*/, char ** argv)
     //
     // Draw text
     //
-    image.fillColor( "red" );
-    image.strokeColor( "red" );
+    image.penColor( "red" );
     image.font( font );
     image.fontPointsize( 18 );
     image.annotate( "Hello world!", "+150+20" );
 
-    image.fillColor( "blue" );
-    image.strokeColor( "blue" );
+    image.penColor( "blue" );
     image.font( font );
     image.fontPointsize( 14 );
     image.annotate( "Goodbye cruel world!", "+150+38" );
 
-    image.fillColor( "black" );
-    image.strokeColor( "black" );
+    image.penColor( "black" );
     image.font( font );
     image.fontPointsize( 14 );
     image.annotate( "I'm climbing the wall!", "+280+120",
-                    NorthWestGravity, 90.0);
+                    NorthWestGravity, 90.0 );
     //image.display();
     //
     // Write image.
     //
 
-    cout << "Writing image \"shapes.miff\" ..." << endl;
-    image.write( "shapes.miff" );
+    cout << "Writing image \"shapes_out.miff\" ..." << endl;
+    image.compressType( RunlengthEncodedCompression );
+    image.write( "shapes_out.miff" );
 
     // cout << "Display image..." << endl;
     // image.display( );
 
   }
-  catch( Exception error_ )
-    {
-      cout << "Caught exception: " << error_.what() << endl;
-      return 1;
-    }
-  catch( exception error_ )
+  catch( exception &error_ )
     {
       cout << "Caught exception: " << error_.what() << endl;
       return 1;
