@@ -199,7 +199,7 @@ void Magick::DrawableEllipse::print (std::ostream& stream_) const
 {
   stream_ << "ellipse "
           << Magick::Coordinate(_originX,_originY)
-	  << " " << _width << "," << _height
+	  << " " << _radiusX << "," << _radiusY
 	  << " " << _arcStart << "," << _arcEnd;
 }
 
@@ -210,6 +210,30 @@ void Magick::DrawableFillColor::print (std::ostream& stream_) const
           << string(_color);
 }
 
+// Specify drawing fill fule
+void Magick::DrawableFillRule::print (std::ostream& stream_) const
+{
+  stream_ << "fill-rule ";
+
+  switch (_fillRule)
+    {
+    case EvenOddRule :
+      {
+        stream_ << "evenodd";
+        break;
+      }
+    case NonZeroRule :
+      {
+        stream_ << "nonzero";
+        break;
+      }
+    default :
+      {
+        stream_ << "none";
+      }
+    }
+}
+
 // Specify drawing fill opacity
 void Magick::DrawableFillOpacity::print (std::ostream& stream_) const
 {
@@ -297,8 +321,68 @@ void Magick::DrawableGravity::print (std::ostream& stream_) const
 // Draw image at point
 void Magick::DrawableCompositeImage::print (std::ostream& stream_) const
 {
-  stream_ << "image "
-          << Magick::Coordinate( _x, _y)
+  stream_ << "image ";
+
+  switch ( _composition )
+    {
+    case OverCompositeOp:
+      stream_ << "Over ";
+      break;
+    case InCompositeOp:
+      stream_ << "In ";
+      break;
+    case OutCompositeOp:
+      stream_ << "Out ";
+      break;
+    case AtopCompositeOp:
+      stream_ << "Atop ";
+      break;
+    case XorCompositeOp:
+      stream_ << "Xor ";
+      break;
+    case PlusCompositeOp:
+      stream_ << "Plus ";
+      break;
+    case MinusCompositeOp:
+      stream_ << "Minus ";
+      break;
+    case AddCompositeOp:
+      stream_ << "Add ";
+      break;
+    case SubtractCompositeOp:
+      stream_ << "Subtract ";
+      break;
+    case DifferenceCompositeOp:
+      stream_ << "Difference ";
+      break;
+    case MultiplyCompositeOp:
+      stream_ << "Multiply ";
+      break;
+    case BumpmapCompositeOp:
+      stream_ << "Bumpmap ";
+      break;
+    case CopyCompositeOp:
+      stream_ << "Copy ";
+      break;
+    case CopyRedCompositeOp:
+      stream_ << "CopyRed ";
+      break;
+    case CopyGreenCompositeOp:
+      stream_ << "CopyGreen ";
+      break;
+    case CopyBlueCompositeOp:
+      stream_ << "CopyBlue ";
+      break;
+    case CopyOpacityCompositeOp:
+      stream_ << "CopyOpacity ";
+      break;
+    default:
+        {
+          stream_ << "Copy ";
+        }
+    }
+
+  stream_ << Magick::Coordinate( _x, _y)
           << " "
           << Magick::Coordinate( _width, _height)
           << " \"";
@@ -361,7 +445,7 @@ void Magick::DrawablePoint::print (std::ostream& stream_) const
 // Text pointsize
 void Magick::DrawablePointSize::print (std::ostream& stream_) const
 {
-  stream_ << "pointsize "
+  stream_ << "font-size "
           << _pointSize;
 }
 
@@ -447,6 +531,107 @@ void Magick::DrawableSkewY::print (std::ostream& stream_) const
   stream_ << "skewY " << _angle;
 }
 
+// Stroke dasharray
+Magick::DrawableDashArray::DrawableDashArray( const unsigned int* dasharray_ )
+  : _dasharray(0)
+{
+  dasharray( dasharray_ );
+}
+void Magick::DrawableDashArray::dasharray( const unsigned int* dasharray_ )
+{
+  LiberateMemory(reinterpret_cast<void**>(&_dasharray));
+
+  if(dasharray_)
+    {
+      // Count elements in dash array
+      int x;
+      for (x=0; dasharray_[x]; x++);
+      // Allocate elements
+      _dasharray=static_cast<unsigned int*>(AcquireMemory((x+1)*sizeof(unsigned int)));
+      // Copy elements
+      memcpy(_dasharray,dasharray_,
+             (x+1)*sizeof(unsigned int));
+    }
+}
+void Magick::DrawableDashArray::print (std::ostream& stream_) const
+{
+  stream_ << "stroke-dasharray ";
+  if( _dasharray )
+    {
+      int x;
+      for (x=0; _dasharray[x]; x++)
+        {
+          if(x)
+            stream_ << ",";
+          stream_ << _dasharray[x];
+        }
+    }
+  else
+    {
+      stream_ << "none";
+    }
+}
+
+// Stroke dashoffset
+void Magick::DrawableDashOffset::print (std::ostream& stream_) const
+{
+  stream_ << "stroke-dashoffset " << _offset;
+}
+
+// Stroke linecap
+void Magick::DrawableStrokeLineCap::print (std::ostream& stream_) const
+{
+  stream_ << "stroke-linecap ";
+
+  switch( _linecap )
+    {
+    case ButtCap :
+      stream_ << "butt";
+      break;
+    case RoundCap :
+      stream_ << "round";
+      break;
+    case SquareCap :
+      stream_ << "square";
+      break;
+    case UndefinedCap :
+    default :
+      {
+        stream_ << "none";
+      }
+    }
+}
+
+// Stroke linejoin
+void Magick::DrawableStrokeLineJoin::print (std::ostream& stream_) const
+{
+  stream_ << "stroke-linejoin ";
+
+  switch( _linejoin )
+    {
+    case MiterJoin :
+      stream_ << "miter";
+      break;
+    case RoundJoin :
+      stream_ << "round";
+      break;
+    case BevelJoin :
+      stream_ << "bevel";
+      break;
+    case UndefinedJoin :
+    default :
+      {
+        stream_ << "none";
+      }
+    }
+}
+
+// Stroke miterlimit
+void Magick::DrawableMiterLimit::print (std::ostream& stream_) const
+{
+  stream_ << "stroke-miterlimit " << _miterlimit;
+}
+
 // Stroke color
 void Magick::DrawableStrokeColor::print (std::ostream& stream_) const
 {
