@@ -162,7 +162,7 @@ Magick::Image::~Image()
 {
   bool doDelete = false;
   {
-    Lock( _imgRef->_mutexLock );
+    Lock( &_imgRef->_mutexLock );
     if ( --_imgRef->_refCount == 0 )
       doDelete = true;
   }
@@ -754,8 +754,6 @@ void Magick::Image::floodFillTexture( unsigned int x_, unsigned int y_,
                           FloodfillMethod // const PaintMethod method
       );
 
-  // Reset to no texture
-  options()->penTexture(0);
   throwImageException();
 }
 void Magick::Image::floodFillTexture( const Magick::Geometry &point_,
@@ -785,8 +783,6 @@ void Magick::Image::floodFillTexture( unsigned int x_, unsigned int y_,
                         FillToBorderMethod // const PaintMethod method
                         );
 
-  // Reset to no texture
-  options()->penTexture(0);
   throwImageException();
 }
 void  Magick::Image::floodFillTexture( const Magick::Geometry &point_,
@@ -1446,7 +1442,7 @@ void Magick::Image::transparent ( const Color &color_ )
   std::string color = color_;
 
   modifyImage();
-  TransparentImage ( image(), color_ );
+  TransparentImage ( image(), color_, TransparentOpacity );
   throwImageException();
 }
 
@@ -2109,9 +2105,11 @@ double Magick::Image::fontPointsize ( void ) const
 
 std::string Magick::Image::format ( void ) const
 {
+  ExceptionInfo exception;
   //  return options()->format ( );
+  GetExceptionInfo(&exception);
   const MagickInfo * magick_info
-  = GetMagickInfo( constImage()->magick );
+  = GetMagickInfo( constImage()->magick , &exception);
 
   if (( magick_info != 0 ) && 
       ( *magick_info->description != '\0' ))
@@ -2356,7 +2354,7 @@ void Magick::Image::penColor ( const Color &penColor_ )
 {
   modifyImage();
   options()->fillColor(penColor_);
-  options()->strokeColor(Color());
+  options()->strokeColor(penColor_);
 }
 Magick::Color Magick::Image::penColor ( void  ) const
 {
@@ -2797,7 +2795,7 @@ double Magick::Image::yResolution ( void ) const
 Magick::Image::Image( const Image & image_ )
   : _imgRef(image_._imgRef)
 {
-  Lock( _imgRef->_mutexLock );
+  Lock( &_imgRef->_mutexLock );
 
   // Increase reference count
   ++_imgRef->_refCount;
@@ -2807,13 +2805,13 @@ Magick::Image::Image( const Image & image_ )
 Magick::Image Magick::Image::operator=( const Magick::Image &image_ )
 {
   {
-    Lock(image_._imgRef->_mutexLock);
+    Lock( &image_._imgRef->_mutexLock );
     ++image_._imgRef->_refCount;
   }
 
   bool doDelete = false;
   {
-    Lock( _imgRef->_mutexLock );
+    Lock( &_imgRef->_mutexLock );
     if ( --_imgRef->_refCount == 0 )
       doDelete = true;
   }
@@ -2917,7 +2915,7 @@ Magick::Image::Image ( MagickLib::Image* image_, Magick::Options* options_ )
 //
 MagickLib::Image * Magick::Image::replaceImage( MagickLib::Image* replacement_ )
 {
-  Lock( _imgRef->_mutexLock );
+  Lock( &_imgRef->_mutexLock );
   if ( _imgRef->_refCount == 1 )
     {
       // We own the image, just replace it
@@ -2949,7 +2947,7 @@ void Magick::Image::modifyImage( void )
 {
   // Nothing to do if we are sole owner of image
   {
-    Lock( _imgRef->_mutexLock );
+    Lock( &_imgRef->_mutexLock );
     if ( _imgRef->_refCount == 1 )
       return;
   }
@@ -3052,8 +3050,6 @@ namespace Magick
   public:
     ~MagickCleanUp( void )
       {
-	DestroyMagickInfo();
-	DestroyDelegateInfo();
       }
   };
 
