@@ -96,19 +96,40 @@ namespace Magick
     
     // Add noise to image with specified noise type
     void            addNoise ( NoiseType noiseType_ );
-    
+
+    //
     // Annotate image (draw text on image)
+    //
+
+    // Gravity effects text placement in bounding area according to rules:
+    //  NorthWestGravity  text bottom-left corner placed at top-left
+    //  NorthGravity      text bottom-center placed at top-center
+    //  NorthEastGravity  text bottom-right corner placed at top-right
+    //  WestGravity       text left-center placed at left-center
+    //  CenterGravity     text center placed at center
+    //  EastGravity       text right-center placed at right-center
+    //  SouthWestGravity  text top-left placed at bottom-left
+    //  SouthGravity      text top-center placed at bottom-center
+    //  SouthEastGravity  text top-right placed at bottom-right
+
+    // Annotate using specified text, and placement location
     void            annotate ( const std::string &text_,
 			       const Geometry &location_ );
+    // Annotate using specified text, bounding area, and placement
+    // gravity
     void            annotate ( const std::string &text_,
-			       const Geometry &location_,
+			       const Geometry &boundingArea_,
 			       GravityType gravity_ );
+    // Annotate with text using specified text, bounding area,
+    // placement gravity, and rotation.
     void            annotate ( const std::string &text_,
-			       const Geometry &location_,
+			       const Geometry &boundingArea_,
 			       GravityType gravity_,
 			       double degrees_ );
+    // Annotate with text (bounding area is entire image) and placement
+    // gravity.
     void            annotate ( const std::string &text_,
-			       GravityType gravity_ = NorthWestGravity);
+			       GravityType gravity_ );
     
     // Blur image with specified blur factor
     // The radius_ parameter specifies the radius of the Gaussian, in
@@ -158,7 +179,12 @@ namespace Magick
     
     // Contrast image (enhance intensity differences in image)
     void            contrast ( unsigned int sharpen_ );
-    
+
+    // Convolve image.  Applies a user-specfied convolution to the image.
+    //  order_ represents the number of columns and rows in the filter kernel.
+    //  kernel_ is an array of doubles representing the convolution kernel.
+    void            convolve ( unsigned int order_, const double *kernel_ );
+
     // Crop image (subregion of original image)
     void            crop ( const Geometry &geometry_ );
     
@@ -192,6 +218,9 @@ namespace Magick
     // Equalize image (histogram equalization)
     void            equalize ( void );
 
+    // Erase image to current "background color"
+    void            erase ( void );
+    
     // Flip image (reflect each scanline in the vertical direction)
     void            flip ( void );
 
@@ -257,8 +286,8 @@ namespace Magick
     // Label image
     void            label ( const std::string &label_ );
     
-    // Extract layer from image
-    void            layer ( LayerType layer_ );
+    // Extract channel from image
+    void            channel ( ChannelType channel_ );
     
     // Magnify image by integral size
     void            magnify ( void );
@@ -410,7 +439,7 @@ namespace Magick
     // Swirl image (image pixels are rotated by degrees)
     void            swirl ( double degrees_ );
     
-    // Layer a texture on image background
+    // Channel a texture on image background
     void            texture ( const Image &texture_ );
     
     // Threshold image
@@ -428,6 +457,23 @@ namespace Magick
     // Trim edges that are the background color from the image
     void            trim ( void );
 
+    // Replace image with a sharpened version of the original image
+    // using the unsharp mask algorithm.
+    //  radius_
+    //    the radius of the Gaussian, in pixels, not counting the
+    //    center pixel.
+    //  sigma_
+    //    the standard deviation of the Gaussian, in pixels.
+    //  amount_
+    //    the percentage of the difference between the original and
+    //    the blur image that is added back into the original.
+    // threshold_
+    //   the threshold in pixels needed to apply the diffence amount.
+    void            unsharpmask ( double radius_,
+                                  double sigma_,
+                                  double amount_,
+                                  double threshold_ );
+
     // Map image pixels to a sine wave
     void            wave ( double amplitude_ = 25.0, double wavelength_ = 150.0 );
     
@@ -579,6 +625,10 @@ namespace Magick
     void            fillColor ( const Color &fillColor_ );
     Color           fillColor ( void ) const;
 
+    // Rule to use when filling drawn objects
+    void            fillRule ( const FillRule &fillRule_ );
+    FillRule        fillRule ( void ) const;
+
     // Filter to use when resizing image
     void            filterType ( FilterTypes filterType_ );
     FilterTypes      filterType ( void ) const;
@@ -622,16 +672,17 @@ namespace Magick
 
     // Image label
     std::string     label ( void ) const;
-    
-    // Linewidth for drawing vector objects (default one)
+
+    // Stroke width for drawing vector objects (default one)
+    // This method is now deprecated. Please use strokeWidth instead.
     void            lineWidth ( double lineWidth_ );
     double          lineWidth ( void ) const;
-    
+
     // File type magick identifier (.e.g "GIF")
     void            magick ( const std::string &magick_ );
     std::string     magick ( void ) const;
     
-    // Image supports transparency (matte layer)
+    // Image supports transparency (matte channel)
     void            matte ( bool matteFlag_ );
     bool            matte ( void ) const;
     
@@ -642,7 +693,7 @@ namespace Magick
     // The mean error per pixel computed when an image is color reduced
     double          meanErrorPerPixel ( void ) const;
 
-    // Tile size and offset within an image montage
+   // Tile size and offset within an image montage
     Geometry        montageGeometry ( void ) const;
 
     // Transform image to black and white
@@ -657,7 +708,7 @@ namespace Magick
     // color reduced.
     double          normalizedMeanError ( void ) const;
 
-    // Pen color
+    // Pen color (same as fill)
     void            penColor ( const Color &penColor_ );
     Color           penColor ( void  ) const;
 
@@ -718,10 +769,55 @@ namespace Magick
     void            size ( const Geometry &geometry_ );
     Geometry        size ( void ) const;
 
-    // Color to use when drawing object outlines
+     // enabled/disable stroke anti-aliasing
+    void            strokeAntiAlias( bool flag_ );
+    bool            strokeAntiAlias( void ) const;
+
+	// Color to use when drawing object outlines
     void            strokeColor ( const Color &strokeColor_ );
     Color           strokeColor ( void ) const;
 
+    // Specify the pattern of dashes and gaps used to stroke
+    // paths. The strokeDashArray represents a zero-terminated array
+    // of numbers that specify the lengths of alternating dashes and
+    // gaps in pixels. If an odd number of values is provided, then
+    // the list of values is repeated to yield an even number of
+    // values.  A typical strokeDashArray_ array might contain the
+    // members 5 3 2 0, where the zero value indicates the end of the
+    // pattern array.
+    void            strokeDashArray ( const unsigned int* strokeDashArray_ );
+    const unsigned int* strokeDashArray ( void ) const;
+
+    // While drawing using a dash pattern, specify distance into the
+    // dash pattern to start the dash (default 0).
+    void            strokeDashOffset ( unsigned int strokeDashOffset_ );
+    unsigned int    strokeDashOffset ( void ) const;
+
+    // Specify the shape to be used at the end of open subpaths when
+    // they are stroked. Values of LineCap are UndefinedCap, ButtCap,
+    // RoundCap, and SquareCap.
+    void            strokeLineCap ( LineCap lineCap_ );
+    LineCap         strokeLineCap ( void ) const;
+    
+    // Specify the shape to be used at the corners of paths (or other
+    // vector shapes) when they are stroked. Values of LineJoin are
+    // UndefinedJoin, MiterJoin, RoundJoin, and BevelJoin.
+    void            strokeLineJoin ( LineJoin lineJoin_ );
+    LineJoin        strokeLineJoin ( void ) const;
+
+    // Specify miter limit. When two line segments meet at a sharp
+    // angle and miter joins have been specified for 'lineJoin', it is
+    // possible for the miter to extend far beyond the thickness of
+    // the line stroking the path. The miterLimit' imposes a limit on
+    // the ratio of the miter length to the 'lineWidth'. The default
+    // value of this parameter is 4.
+    void            strokeMiterLimit ( unsigned int miterLimit_ );
+    unsigned int    strokeMiterLimit ( void ) const;
+
+    // Stroke width for drawing vector objects (default one)
+    void            strokeWidth ( double strokeWidth_ );
+    double          strokeWidth ( void ) const;
+
     // Subimage of an image sequence
     void            subImage ( unsigned int subImage_ );
     unsigned int    subImage ( void ) const;
@@ -782,8 +878,7 @@ namespace Magick
     // Low-level Pixel Access Routines
     //
     // Also see the Pixels class, which provides support for multiple
-    // cache views. The low-level pixel access routines in the Image
-    // class are provided in order to support backward compatability.
+    // cache views.
     //
     //////////////////////////////////////////////////////////////////////
 
@@ -847,7 +942,7 @@ namespace Magick
     void            throwImageException( void );
 
   private:
-    ImageRef *                       _imgRef;
+    ImageRef *      _imgRef;
   };
 
 
@@ -925,6 +1020,16 @@ inline void Magick::Image::reduceNoise ( void )
   reduceNoise( 3 );
 }
 
+// Stroke width for drawing vector objects (default one)
+inline void Magick::Image::lineWidth ( double lineWidth_ )
+{
+  strokeWidth( lineWidth_ );
+}
+inline double Magick::Image::lineWidth ( void ) const
+{
+  return strokeWidth( );
+}
+
 // Get MagickLib::Image*
 inline MagickLib::Image*& Magick::Image::image( void )
 {
