@@ -122,13 +122,13 @@ int main( int /*argc*/, char ** argv)
     //
 
     // Test default value
-    if ( image.animationIterations() != 0 )
+    if ( image.animationIterations() != 1 )
       {
 	++failures;
 	cout << "Line: " << __LINE__
              << ", animationIterations default ("
 	     << image.animationIterations()
-	     << ") not 0 as expected" << endl;
+	     << ") not 1 as expected" << endl;
       }
 
     // Test setting to 0
@@ -690,15 +690,6 @@ int main( int /*argc*/, char ** argv)
     //
     // font
     //
-    // Test default
-    if ( image.font().length() != 11 )
-      {
-	++failures;
-	cout << "Line: " << __LINE__
-             << ", font has default length " << image.font().length()
-             << " rather than 13 as expected"
-             << endl;
-      }
 
     // Test set/get
     image.font("helvetica");
@@ -719,13 +710,13 @@ int main( int /*argc*/, char ** argv)
     // fontPointsize
     //
     // Test default
-    if ( image.fontPointsize() != 13 )
+    if ( image.fontPointsize() != 12 )
       {
 	++failures;
 	cout << "Line: " << __LINE__
              << ", fontPointsize ("
              << image.fontPointsize()
-             << ") is not default of 13 as expected"
+             << ") is not default of 12 as expected"
              << endl;
       }
 
@@ -1016,6 +1007,33 @@ int main( int /*argc*/, char ** argv)
 	     << ") set/get failed" << endl;
       }
 
+    //
+    // strokeColor
+    //
+
+    image.strokeColor(ColorRGB(0.5,0.5,1));
+    if ( image.strokeColor() != ColorRGB(0.5,0.5,1) )
+      {
+	++failures;
+	cout << "Line: " << __LINE__ << ", strokeColor ("
+	     << string(image.strokeColor())
+	     << ") set/get failed" << endl;
+      }
+
+
+    //
+    // fillColor
+    //
+
+    image.fillColor(ColorRGB(0.5,0.5,1));
+    if ( image.fillColor() != ColorRGB(0.5,0.5,1) )
+      {
+	++failures;
+	cout << "Line: " << __LINE__ << ", fillColor ("
+	     << string(image.fillColor())
+	     << ") set/get failed" << endl;
+      }
+
     //
     // pixelColor
     //
@@ -1083,11 +1101,11 @@ int main( int /*argc*/, char ** argv)
     // quantizeColors
     //
     // Test default
-    if ( image.quantizeColors() != 0 )
+    if ( image.quantizeColors() != 256 )
       {
 	++failures;
 	cout << "Line: " << __LINE__
-             << ", quantizeColors is not zero as expected" << endl;
+             << ", quantizeColors is not 256 as expected" << endl;
       }
 
     // Test set/get
@@ -1433,12 +1451,12 @@ int main( int /*argc*/, char ** argv)
       }
 
   }
-  catch( Exception error_ )
+  catch( Exception &error_ )
     {
       cout << "Caught exception: " << error_.what() << endl;
       return 1;
     }
-  catch( exception error_ )
+  catch( exception &error_ )
     {
       cout << "Caught exception: " << error_.what() << endl;
       return 1;
