@@ -40,12 +40,12 @@ int main( int /*argc*/, char ** argv)
     coalesceImages( imageList.begin(), imageList.end() );
   }
 
-  catch( Exception error_ )
+  catch( Exception &error_ )
     {
       cout << "Caught exception: " << error_ << endl;
       return 1;
     }
-  catch( exception error_ )
+  catch( exception &error_ )
     {
       cout << "Caught exception: " << error_.what() << endl;
       return 1;
