@@ -19,15 +19,13 @@ for ($i=0; $i < 300; $i+=10)
 #
 # Draw rounded rectangle.
 #
-$image->Draw(primitve=>'RoundRectangle',fill=>blue,stroke=>'red',
-  points=>'15,15 70,70 10,10');
-$image->Draw(primitve=>'roundRectangle',stroke=>maroon,linewidth=>4,
-  points=>'15,15 70,70 10,10');
+$image->Draw(primitve=>'RoundRectangle',fill=>'blue',stroke=>'maroon',
+  stroke_width=>4,points=>'30,30 100,100 10,10');
 #
 # Draw curve.
 #
 $image->Draw(primitve=>'bezier',points=>'20,20, 100,50, 50,100, 160,160',
-  stroke=>black,linewidth=>4);
+  fill=>'none',stroke=>'black',stroke_width=>4);
 #
 # Draw line.
 #
@@ -35,28 +33,33 @@ $image->Draw(primitive=>'line',points=>"10,200 20,190",stroke=>red);
 #
 # Draw arc within a circle.
 #
-$image->Draw(primitive=>'circle',stroke=>'black',fill=>'yellow',linewidth=>4,
-  points=>"160,70 200,70");
-$image->Draw(primitve=>'Path',stroke=>'black',fill=>'blue',linewidth=>4,
-  points=>'M160,70 v-40 a40,40 0 0,0 -40,40 z');
+$image->Draw(primitive=>'circle',stroke=>'none',fill=>'yellow',,
+  points=>"170,70 200,70");
+$image->Draw(primitve=>'Path',stroke=>'none',fill=>'blue',stroke_width=>4,
+  points=>'M170,70 v-30 a30,30 0 0,0 -30,30 z');
+$image->Draw(primitive=>'circle',stroke=>'black',fill=>'none',stroke_width=>4,
+  points=>"170,70 200,70");
 #
 # Draw pentogram.
 #
 $image->Draw(primitive=>'polygon',
   points=>"160,120 130,190 210,145 110,145 190,190 160,120",stroke=>red,
-  fill=>LimeGreen,linewidth=>3);
+  fill=>LimeGreen,stroke_width=>3);
 #
 # Draw rectangle.
 #
-$image->Draw(primitve=>'rectangle',points=>'200,200 260,260',stroke=>yellow,
-  linewidth=>5);
-$image->Draw(primitve=>'line',points=>'200,260 260,260',stroke=>green,
-  linewidth=>5);
+$image->Draw(primitve=>'line',points=>'200,260 200,200',stroke=>yellow,
+  stroke_width=>5);
+$image->Draw(primitve=>'line',points=>'200,200 260,200',stroke=>yellow,
+  stroke_width=>5);
 $image->Draw(primitve=>'line',points=>'260,200 260,260',stroke=>red,
-  linewidth=>5);
+  stroke_width=>5);
+$image->Draw(primitve=>'line',points=>'200,260 260,260',stroke=>green,
+  stroke_width=>5);
 #
 # Draw text.
 #
 $image->Annotate(text=>'This is a test!',geometry=>'+30+140',
-  font=>'@Generic.ttf',fill=>'green',pointsize=>24,rotate=>-45.0);
-$image->Display();
+  font=>'Generic.ttf',fill=>'green',pointsize=>24,rotate=>45.0);
+$image->Write('piddle.gif');
+$image->Write('win:');
