@@ -125,41 +125,35 @@ register IndexPacket *indexes;
            indexes=GetIndexes(image);
            for (x=0; x < ((int) image->columns-1); x+=2)
                  {
-                 index=(*p >> 6) & 0x3;
-		 if(index>=image->colors) index=image->colors-1;
+                 index=ValidateColormapIndex(image,(*p >> 6) & 0x3);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-		 index=(*p >> 4) & 0x3;
-		 if(index>=image->colors) index=image->colors-1;
+		 index=ValidateColormapIndex(image,(*p >> 4) & 0x3);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-		 index=(*p >> 2) & 0x3;
-		 if(index>=image->colors) index=image->colors-1;
+		 index=ValidateColormapIndex(image,(*p >> 2) & 0x3);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-                 index=(*p) & 0x3;
-		 if(index>=image->colors) index=image->colors-1;
+                 index=ValidateColormapIndex(image,(*p) & 0x3);
                  indexes[x+1]=index;
                  *q++=image->colormap[index];
 		 p++;
                  }
            if ((image->columns % 4) != 0)
                  {
-                   index=(*p >> 6) & 0x3;
-		   if(index>=image->colors) index=image->colors-1;
+                   index=ValidateColormapIndex(image,(*p >> 6) & 0x3);
                    indexes[x]=index;
                    *q++=image->colormap[index];
 		   if ((image->columns % 4) >= 1)
 
 		      {
-		      index=(*p >> 4) & 0x3;
-		      if(index>=image->colors) index=image->colors-1;
+		      index=ValidateColormapIndex(image,(*p >> 4) & 0x3);
                       indexes[x]=index;
                       *q++=image->colormap[index];
 		      if ((image->columns % 4) >= 2)
 
 		        {
-		        index=(*p >> 2) & 0x3;
+		        index=ValidateColormapIndex(image,(*p >> 2) & 0x3);
                         indexes[x]=index;
                         *q++=image->colormap[index];
 		        }
@@ -182,20 +176,17 @@ register IndexPacket *indexes;
            indexes=GetIndexes(image);
            for (x=0; x < ((int) image->columns-1); x+=2)
                  {
-                 index=(*p >> 4) & 0xf;
-		 if(index>=image->colors) index=image->colors-1;
+                 index=ValidateColormapIndex(image,(*p >> 4) & 0xf);
 		 indexes[x]=index;
                  *q++=image->colormap[index];
-                 index=(*p) & 0xf;
-		 if(index>=image->colors) index=image->colors-1;
+                 index=ValidateColormapIndex(image,(*p) & 0xf);
                  indexes[x+1]=index;
                  *q++=image->colormap[index];
                  p++;
                  }
            if ((image->columns % 2) != 0)
                  {
-                   index=(*p >> 4) & 0xf;
-		   if(index>=image->colors) index=image->colors-1;
+                   index=ValidateColormapIndex(image,(*p >> 4) & 0xf);
                    indexes[x]=index;
                    *q++=image->colormap[index];
                    p++;
@@ -215,10 +206,10 @@ register IndexPacket *indexes;
 
 	   for (x=0; x < (int) image->columns; x++)
                 {
-                index=(*p++);
-		if(index>=image->colors) index=image->colors-1;
+                index=ValidateColormapIndex(image,*p);
                 indexes[x]=index;
                 *q++=image->colormap[index];
+                p++;
                 }
            if (!SyncImagePixels(image))
                  break;
@@ -339,9 +330,9 @@ CUT_KO:  ThrowReaderException(CorruptImageWarning,"Not a CUT image file",image);
 	}
  if(EncodedByte!=1) goto CUT_KO;	/*wrong data: size incorrect*/
  i=0;				/*guess a number of bit planes*/
- if(ldblk==Header.Width)   i=8;
- if(2*ldblk==Header.Width) i=4;
- if(8*ldblk==Header.Width) i=1;
+ if(ldblk==(int) Header.Width)   i=8;
+ if(2*ldblk==(int) Header.Width) i=4;
+ if(8*ldblk==(int) Header.Width) i=1;
  if(i==0) goto CUT_KO;		/*wrong data: incorrect bit planes*/
 
  image->columns=Header.Width;
@@ -421,7 +412,7 @@ ErasePalette:
    if(PalHeader.MaxGreen==0) PalHeader.MaxGreen=MaxRGB;
    if(PalHeader.MaxBlue==0) PalHeader.MaxBlue=MaxRGB;
    
-   for(i=0;i<=PalHeader.MaxIndex;i++)
+   for(i=0;i<=(int) PalHeader.MaxIndex;i++)
            {      /*this may be wrong- I don't know why is palette such strange*/
 	   j=TellBlob(palette);
 	   if((j % 512)>512-/*sizeof(pal)*/6)
@@ -478,7 +469,7 @@ NoMemory:  ThrowReaderException(ResourceLimitWarning,"Memory allocation failed",
  if(BImgBuff==NULL) goto NoMemory;
 
  SeekBlob(image,6 /*sizeof(Header)*/,SEEK_SET);
- for(i=0;i<Header.Height;i++)
+ for(i=0;i<(int) Header.Height;i++)
       {
       EncodedByte=ReadBlobLSBShort(image);
 
