@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright (C) 2000 ImageMagick Studio, a non-profit organization dedicated %
+%  Copyright (C) 2001 ImageMagick Studio, a non-profit organization dedicated %
 %  to making software imaging solutions freely available.                     %
 %                                                                             %
 %  Permission is hereby granted, free of charge, to any person obtaining a    %
@@ -126,7 +126,7 @@ static Image *ReadICMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->color_profile.info=(unsigned char *) AcquireMemory(length);
   for (q=image->color_profile.info; ; q++)
   {
-    c=ReadByte(image);
+    c=ReadBlobByte(image);
     if (c == EOF)
       break;
     if ((q-image->color_profile.info+1) >= (int) length)
