@@ -294,8 +294,7 @@ static unsigned int DecodeImage(Image *image,unsigned char *luma,
       quantum=(long) (*q)+r->key;
     else
       quantum=(long) (*q)+r->key-256;
-    *q=(unsigned char)
-      ((quantum < 0) ? 0 : (quantum > MaxRGB) ? MaxRGB : quantum);
+    *q=(unsigned char) ((quantum < 0) ? 0 : (quantum > 255) ? 255 : quantum);
     q++;
     PCDGetBits(r->length);
     count--;
@@ -733,13 +732,9 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         Rotate image.
       */
       degrees=rotate == 1 ? -90.0 : 90.0;
-      image->orphan=True;
       rotated_image=RotateImage(image,degrees,exception);
       if (rotated_image != (Image *) NULL)
-        {
-          DestroyImage(image);
-          image=rotated_image;
-        }
+        image=rotated_image;
     }
   /*
     Set CCIR 709 primaries with a D65 white point.
@@ -985,7 +980,6 @@ static unsigned int WritePCDImage(const ImageInfo *image_info,Image *image)
       /*
         Rotate portrait to landscape.
       */
-      image->orphan=True;
       rotated_image=RotateImage(image,90.0,&image->exception);
       if (rotated_image == (Image *) NULL)
         return(False);
