@@ -173,7 +173,7 @@ static unsigned int PNMInteger(Image *image,const unsigned int base)
         if (comment != (char *) NULL)
           for ( ; (c != EOF) && (c != '\n'); p++)
           {
-            if ((p-comment) >= length)
+            if ((p-comment) >= (int) length)
               {
                 length<<=1;
                 length+=MaxTextExtent;
@@ -360,7 +360,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           indexes=GetIndexes(image);
           for (x=0; x < (int) image->columns; x++)
           {
-            index=!PNMInteger(image,2);
+            index=ValidateColormapIndex(image,!PNMInteger(image,2));
             indexes[x]=index;
             *q++=image->colormap[index];
           }
@@ -385,7 +385,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           indexes=GetIndexes(image);
           for (x=0; x < (int) image->columns; x++)
           {
-            index=PNMInteger(image,10);
+            index=ValidateColormapIndex(image,PNMInteger(image,10));
             indexes[x]=index;
             *q++=image->colormap[index];
           }
@@ -493,15 +493,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           for (x=0; x < (int) image->columns; x++)
           {
             if (image->depth <= 8)
-              index=(*p++);
+              index=ValidateColormapIndex(image,*p++);
             else
               {
-                index=(*p++) << 8;
-                index|=(*p++);
+                index=ValidateColormapIndex(image,(*p << 8) | *(p+1));
+                p+=2;
               }
-            if (index >= image->colors)
-              ThrowReaderException(CorruptImageWarning,"invalid colormap index",
-                image);
             indexes[x]=index;
             *q++=image->colormap[index];
           }
@@ -783,7 +780,6 @@ static unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
       Promote/Demote image based on image type.
     */
     TransformRGBImage(image,RGBColorspace);
-    (void) IsPseudoClass(image);
     if (LocaleCompare(image_info->magick,"PPM") == 0)
       image->storage_class=DirectClass;
     magick=(char *) image_info->magick;
@@ -804,7 +800,7 @@ static unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
     /*
       Write PNM file header.
     */
-    if (!IsPseudoClass(image) && !IsGrayImage(image))
+    if (image->storage_class == DirectClass)
       {
         /*
           Full color PNM image.
@@ -926,7 +922,7 @@ static unsigned int WritePNMImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (int) image->columns; x++)
           {
-            index=(short unsigned int) Intensity(*p);
+            index=Intensity(*p);
             FormatString(buffer,"%d ",index);
             (void) WriteBlobString(image,buffer);
             i++;
