@@ -139,7 +139,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define DocumentMedia  "%%DocumentMedia:"
 #define PageBoundingBox  "%%PageBoundingBox:"
 #define PostscriptLevel  "%!PS-"
-#define ShowPage  "showpage"
 
   char
     density[MaxTextExtent],
@@ -151,7 +150,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     translate_geometry[MaxTextExtent];
 
   DelegateInfo
-    delegate_info;
+    *delegate_info;
 
   double
     dx_resolution,
@@ -189,19 +188,22 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     bounds;
 
   unsigned int
-    eps_level,
     height,
     level,
     width;
 
   if (image_info->monochrome)
     {
-      if (!GetDelegateInfo("gs-mono",(char *) NULL,&delegate_info))
+      delegate_info=GetDelegateInfo("gs-mono",(char *) NULL,exception);
+      if (delegate_info == (DelegateInfo *) NULL)
         return((Image *) NULL);
     }
   else
-    if (!GetDelegateInfo("gs-color",(char *) NULL,&delegate_info))
-      return((Image *) NULL);
+    {
+      delegate_info=GetDelegateInfo("gs-color",(char *) NULL,exception);
+      if (delegate_info == (DelegateInfo *) NULL)
+        return((Image *) NULL);
+    }
   /*
     Open image file.
   */
@@ -235,8 +237,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   page.height=792;
   page.x=0;
   page.y=0;
-  (void) ParseImageGeometry(PSPageGeometry,&page.x,&page.y,
-    &page.width,&page.height);
+  (void) ParseImageGeometry(PSPageGeometry,&page.x,&page.y,&page.width,
+    &page.height);
   /*
     Determine page geometry from the Postscript bounding box.
   */
@@ -255,7 +257,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   box.width=0;
   box.height=0;
   level=0;
-  eps_level=0;
   p=command;
   for (i=0; (LocaleCompare(image_info->magick,"EPT") != 0) || i < filesize; i++)
   {
@@ -268,10 +269,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       continue;
     *p='\0';
     p=command;
-    if (LocaleNCompare(PostscriptLevel,command,Extent(PostscriptLevel)) == 0)
-      (void) sscanf(command,"%%!PS-Adobe-%d.0 EPSF-%d.0",&level,&eps_level);
-    if (LocaleNCompare(ShowPage,command,Extent(ShowPage)) == 0)
-      eps_level=0;
     /*
       Parse a bounding box statement.
     */
@@ -287,14 +284,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         &bounds.x1,&bounds.y1,&bounds.x2,&bounds.y2);
     if (count != 4)
       continue;
-    if ((bounds.x1 > bounds.x2) ||
-        (bounds.y1 > bounds.y2))
+    if ((bounds.x1 > bounds.x2) || (bounds.y1 > bounds.y2))
       continue;
     /*
       Set Postscript render geometry.
     */
-    FormatString(translate_geometry,"%f %f translate\n",-bounds.x1,
-      -bounds.y1);
+    FormatString(translate_geometry,"%f %f translate\n",-bounds.x1,-bounds.y1);
     width=(unsigned int) (bounds.x2-bounds.x1);
     if ((float) ((int) bounds.x2) != bounds.x2)
       width++;
@@ -307,14 +302,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     page.height=height;
     box=page;
   }
-  if (eps_level != 0)
-    (void) fputs("showpage\n",file);
   if (image_info->page != (char *) NULL)
-    (void) ParseImageGeometry(image_info->page,&page.x,&page.y,
-      &page.width,&page.height);
+    (void) ParseImageGeometry(image_info->page,&page.x,&page.y,&page.width,
+      &page.height);
   FormatString(geometry,"%ux%u",
-    (unsigned int) ceil(page.width*image->x_resolution/dx_resolution),
-    (unsigned int) ceil(page.height*image->y_resolution/dy_resolution));
+    (unsigned int) ceil(page.width*image->x_resolution/dx_resolution-0.5),
+    (unsigned int) ceil(page.height*image->y_resolution/dy_resolution-0.5));
   if (ferror(file))
     {
       (void) fclose(file);
@@ -332,15 +325,15 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   *options='\0';
   if (image_info->subrange != 0)
-    FormatString(options,"-dFirstPage=%u -dLastPage=%u",
-      image_info->subimage+1,image_info->subimage+image_info->subrange);
+    FormatString(options,"-dFirstPage=%u -dLastPage=%u",image_info->subimage+1,
+      image_info->subimage+image_info->subrange);
   (void) strcpy(filename,image_info->filename);
   TemporaryFilename((char *) image_info->filename);
-  FormatString(command,delegate_info.commands,image_info->antialias ? 4 : 1,
+  FormatString(command,delegate_info->commands,image_info->antialias ? 4 : 1,
     image_info->antialias ? 4 : 1,geometry,density,options,image_info->filename,
     postscript_filename);
   MagickMonitor(RenderPostscriptText,0,8);
-  status=SystemCommand(image_info->verbose,command);
+  status=ExecutePostscriptInterpreter(image_info->verbose,command);
   if (!IsAccessible(image_info->filename))
     {
       /*
@@ -351,7 +344,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         ThrowReaderException(FileOpenWarning,"Unable to write file",image);
       (void) fputs("showpage\n",file);
       (void) fclose(file);
-      status=SystemCommand(image_info->verbose,command);
+      status=ExecutePostscriptInterpreter(image_info->verbose,command);
     }
   (void) remove(postscript_filename);
   MagickMonitor(RenderPostscriptText,7,8);
@@ -932,7 +925,8 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
           (void) strcpy(buffer,"%%%%BoundingBox: (atend)\n");
         else
           FormatString(buffer,"%%%%BoundingBox: %g %g %g %g\n",
-            floor(bounds.x1),floor(bounds.y1),ceil(bounds.x2),ceil(bounds.y2));
+            floor(bounds.x1+0.5),floor(bounds.y1+0.5),ceil(bounds.x2-0.5),
+            ceil(bounds.y2-0.5));
         (void) WriteBlobString(image,buffer);
         attribute=GetImageAttribute(image,"Label");
         if (attribute != (ImageAttribute *) NULL)
@@ -980,17 +974,18 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Dump image as bitmap.
             */
-            if (!IsMonochromeImage(preview_image))
-              {
-                QuantizeInfo
-                  quantize_info;
-
-                GetQuantizeInfo(&quantize_info);
-                quantize_info.number_colors=2;
-                quantize_info.dither=image_info->dither;
-                quantize_info.colorspace=GRAYColorspace;
-                (void) QuantizeImage(&quantize_info,preview_image);
-              }
+            if (preview_image->storage_class != DirectClass)
+              if (!IsMonochromeImage(preview_image))
+                {
+                  QuantizeInfo
+                    quantize_info;
+  
+                  GetQuantizeInfo(&quantize_info);
+                  quantize_info.number_colors=2;
+                  quantize_info.dither=image_info->dither;
+                  quantize_info.colorspace=GRAYColorspace;
+                  (void) QuantizeImage(&quantize_info,preview_image);
+                }
             polarity=Intensity(preview_image->colormap[0]) < (0.5*MaxRGB);
             if (preview_image->colors == 2)
               polarity=Intensity(preview_image->colormap[0]) >
@@ -1115,7 +1110,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
     i=0;
     index=0;
     x=0;
-    if (!IsPseudoClass(image) && !IsGrayImage(image))
+    if (image->storage_class == DirectClass)
       {
         /*
           Dump DirectClass image.
@@ -1342,7 +1337,7 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (int) image->columns; x++)
                 {
                   if ((index == indexes[x]) && (length < 255) &&
-                      (x < (image->columns-1)))
+                      (x < ((int) image->columns-1)))
                     length++;
                   else
                     {
@@ -1421,8 +1416,8 @@ static unsigned int WritePSImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobString(image,"%%Trailer\n");
   if (page > 2)
     {
-      FormatString(buffer,"%%%%BoundingBox: %g %g %g %g\n",
-        floor(bounds.x1),floor(bounds.y1),ceil(bounds.x2),ceil(bounds.y2));
+      FormatString(buffer,"%%%%BoundingBox: %g %g %g %g\n",floor(bounds.x1+0.5),
+        floor(bounds.y1+0.5),ceil(bounds.x2-0.5),ceil(bounds.y2-0.5));
       (void) WriteBlobString(image,buffer);
     }
   (void) WriteBlobString(image,"%%EOF\n");
