@@ -156,7 +156,7 @@ static unsigned int DecodeImage(const unsigned char *compressed_pixels,
   assert(pixels != (unsigned char *) NULL);
   p=compressed_pixels;
   q=pixels;
-  while ((p-compressed_pixels) < length)
+  while ((p-compressed_pixels) < (int) length)
   {
     byte=(*p++);
     if (byte != 128)
@@ -675,7 +675,7 @@ static unsigned int WriteSUNImage(const ImageInfo *image_info,Image *image)
     sun_info.type=(image->storage_class == DirectClass ? RT_FORMAT_RGB : RT_STANDARD);
     sun_info.maptype=RMT_NONE;
     sun_info.maplength=0;
-    if (!IsPseudoClass(image) && !IsGrayImage(image))
+    if (image->storage_class == DirectClass)
       {
         /*
           Full color SUN raster.
@@ -722,7 +722,7 @@ static unsigned int WriteSUNImage(const ImageInfo *image_info,Image *image)
     */
     x=0;
     y=0;
-    if (!IsPseudoClass(image) && !IsGrayImage(image))
+    if (image->storage_class == DirectClass)
       {
         register unsigned char
           *q;
