@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright (C) 2000 ImageMagick Studio, a non-profit organization dedicated %
+%  Copyright (C) 2001 ImageMagick Studio, a non-profit organization dedicated %
 %  to making software imaging solutions freely available.                     %
 %                                                                             %
 %  Permission is hereby granted, free of charge, to any person obtaining a    %
@@ -131,7 +131,7 @@ static Image *ReadTILEImage(const ImageInfo *image_info,
   for (y=0; y < (int) image->rows; y+=tiled_image->rows)
   {
     for (x=0; x < (int) image->columns; x+=tiled_image->columns)
-      CompositeImage(image,ReplaceCompositeOp,tiled_image,x,y);
+      CompositeImage(image,CopyCompositeOp,tiled_image,x,y);
     MagickMonitor(LoadImageText,y,image->rows);
   }
   DestroyImage(tiled_image);
