@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright (C) 2000 ImageMagick Studio, a non-profit organization dedicated %
+%  Copyright (C) 2001 ImageMagick Studio, a non-profit organization dedicated %
 %  to making software imaging solutions freely available.                     %
 %                                                                             %
 %  Permission is hereby granted, free of charge, to any person obtaining a    %
@@ -55,7 +55,6 @@
 #include "magick.h"
 #include "defines.h"
 
-#if defined(HasTTF)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -89,29 +88,25 @@
 */
 static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  AnnotateInfo
-    *annotate_info;
-
   char
-    geometry[MaxTextExtent],
-    text[MaxTextExtent];
+    filename[MaxTextExtent],
+    geometry[MaxTextExtent];
+
+  FILE
+    *file;
 
   Image
-    *annotate_image,
     *image;
 
+  ImageInfo
+    *clone_info;
+
   int
     y;
 
-  long
-    magick;
-
   register int
     i;
 
-  ImageInfo
-    *clone_info;
-
   unsigned int
     status;
 
@@ -122,105 +117,49 @@ static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   status=OpenBlob(image_info,image,ReadBinaryType);
   if (status == False)
     ThrowReaderException(FileOpenWarning,"Unable to open file",image);
-  magick=MSBFirstReadLong(image);
-  if ((magick != 256) && (magick != 65536))
-    ThrowReaderException(CorruptImageWarning,"Not a TTF font file",image);
-  DestroyImage(image);
   /*
-    Start with a white canvas.
+    Open draw file.
   */
+  TemporaryFilename(filename);
+  file=fopen(filename,"w");
+  if (file == (FILE *) NULL)
+    ThrowReaderException(FileOpenWarning,"Unable to open file",image);
   y=0;
-  clone_info=CloneImageInfo(image_info);
-  if (clone_info == (ImageInfo *) NULL)
-    return((Image *) NULL);
-  (void) CloneString(&clone_info->font,"");
-  FormatString(clone_info->font,"@%.1024s",image_info->filename);
-  annotate_info=CloneAnnotateInfo(clone_info,(AnnotateInfo *) NULL);
-  (void) CloneString(&clone_info->size,"800x480");
-  (void) strcpy(clone_info->filename,"xc:white");
-  image=ReadImage(clone_info,exception);
-  if (image == (Image *) NULL)
-    {
-      DestroyAnnotateInfo(annotate_info);
-      return((Image *) NULL);
-    }
-  (void) strcpy(image->filename,image_info->filename);
-  if (image_info->ping)
-    {
-      DestroyAnnotateInfo(annotate_info);
-      DestroyImageInfo(clone_info);
-      CloseBlob(image);
-      return(image);
-    }
-  clone_info->pointsize=18;
-  /*
-    Annotate canvas with text rendered with font at different point sizes.
-  */
-  y=30;
-  FormatString(clone_info->filename,"label:white");
-  annotate_image=ReadImage(clone_info,exception);
-  DestroyImageInfo(clone_info);
-  if (annotate_image != (Image *) NULL)
-    {
-      ImageAttribute
-        *attribute;
-
-      annotate_info->pointsize=30;
-      FormatString(geometry,"+10%+d",y);
-      (void) CloneString(&annotate_info->geometry,geometry);
-      (void) CloneString(&annotate_info->text,"Unknown family");
-      attribute=GetImageAttribute(annotate_image,"Label");
-      if (attribute != (ImageAttribute *) NULL)
-        (void) CloneString(&annotate_info->text,attribute->value);
-      AnnotateImage(image,annotate_info);
-      DestroyImage(annotate_image);
-      y+=42;
-    }
-  annotate_info->pointsize=18;
-  FormatString(geometry,"+10%+d",y);
-  (void) CloneString(&annotate_info->geometry,geometry);
-  (void) CloneString(&annotate_info->text,"abcdefghijklmnopqrstuvwxyz");
-  AnnotateImage(image,annotate_info);
-  y+=20;
-  FormatString(geometry,"+10%+d",y);
-  (void) CloneString(&annotate_info->geometry,geometry);
-  (void) CloneString(&annotate_info->text,"ABCDEFGHIJKLMNOPQRSTUVWXYZ");
-  AnnotateImage(image,annotate_info);
-  y+=20;
-  FormatString(geometry,"+10%+d",y);
-  (void) CloneString(&annotate_info->geometry,geometry);
-  (void) CloneString(&annotate_info->text,"1234567890.:,;(:*!?')");
-  AnnotateImage(image,annotate_info);
+  (void) fprintf(file,"font %.1024s\n",image_info->filename);
+  (void) fprintf(file,"font-size 18\n");
+  (void) fprintf(file,"text +10%+d 'abcdefghijklmnopqrstuvwxyz'\n",y+=20);
+  (void) fprintf(file,"text +10%+d 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'\n",y+=20);
+  (void) fprintf(file,"text +10%+d '1234567890.:,;(:*!?\")'\n",y+=20);
   y+=20;
   for (i=12; i <= 72; i+=6)
   {
-    y+=i+6;
-    annotate_info->pointsize=18;
-    FormatString(geometry,"+10%+d",y);
-    (void) CloneString(&annotate_info->geometry,geometry);
-    FormatString(text,"%d",i);
-    (void) CloneString(&annotate_info->text,text);
-    AnnotateImage(image,annotate_info);
-    annotate_info->pointsize=i;
-    FormatString(geometry,"+50%+d",y);
-    (void) CloneString(&annotate_info->geometry,geometry);
-    (void) CloneString(&annotate_info->text,
-      "That which does not destroy me, only makes me stronger");
-    AnnotateImage(image,annotate_info);
+    y+=i+12;
+    (void) fprintf(file,"font-size 18\n");
+    (void) fprintf(file,"text +10+%d '%d'\n",y,i);
+    (void) fprintf(file,"font-size %d",i);
+    (void) fprintf(file,
+      "text +50+%d 'That which does not destroy me, only makes me stronger.'\n",
+      y);
     if (i >= 24)
       i+=6;
   }
-  DestroyAnnotateInfo(annotate_info);
+  (void) fclose(file);
+  CloseBlob(image);
+  DestroyImage(image);
+  /*
+    Draw image.
+  */
+  clone_info=CloneImageInfo(image_info);
+  FormatString(geometry,"800x480");
+  CloneString(&clone_info->size,geometry);
+  FormatString(clone_info->filename,"mvg:%.1024s",filename);
+  image=ReadImage(clone_info,exception);
+  if (image != (Image *) NULL)
+    (void) strcpy(image->filename,image_info->filename);
+  (void) remove(filename);
+  DestroyImageInfo(clone_info);
   return(image);
 }
-#else
-static Image *ReadTTFImage(const ImageInfo *image_info,ExceptionInfo *exception)
-{
-  ThrowException(exception,MissingDelegateWarning,"Cannot read TTF images",
-    image_info->filename);
-  return((Image *) NULL);
-}
-#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -256,6 +195,24 @@ ModuleExport void RegisterTTFImage(void)
   entry->description=AllocateString("TrueType font");
   entry->module=AllocateString("TTF");
   RegisterMagickInfo(entry);
+  entry=SetMagickInfo("AFM");
+  entry->decoder=ReadTTFImage;
+  entry->adjoin=False;
+  entry->description=AllocateString("TrueType font");
+  entry->module=AllocateString("TTF");
+  RegisterMagickInfo(entry);
+  entry=SetMagickInfo("PFB");
+  entry->decoder=ReadTTFImage;
+  entry->adjoin=False;
+  entry->description=AllocateString("TrueType font");
+  entry->module=AllocateString("TTF");
+  RegisterMagickInfo(entry);
+  entry=SetMagickInfo("PFM");
+  entry->decoder=ReadTTFImage;
+  entry->adjoin=False;
+  entry->description=AllocateString("TrueType font");
+  entry->module=AllocateString("TTF");
+  RegisterMagickInfo(entry);
 }
 
 /*
@@ -279,7 +236,8 @@ ModuleExport void RegisterTTFImage(void)
 */
 ModuleExport void UnregisterTTFImage(void)
 {
-#if defined(HasTTF)
   UnregisterMagickInfo("TTF");
-#endif
+  UnregisterMagickInfo("AFM");
+  UnregisterMagickInfo("PFB");
+  UnregisterMagickInfo("PFM");
 }
