@@ -14,8 +14,8 @@
 %                                                                             %
 %                                                                             %
 %                              Software Design                                %
-%                              Bob Friesenhahn                                %
-%                               December 2000                                 %
+%                     Bob Friesenhahn & Francis J. Franklin                   %
+%                          December 2000 - May 2001                           %
 %                                                                             %
 %                                                                             %
 %  Copyright (C) 2001 ImageMagick Studio, a non-profit organization dedicated %
@@ -48,7 +48,7 @@
 %
 %
 %
-Work remaining to be completed on this module:
+Work remaining to be completed on libwmf portion of this module:
  - Clipping rectangles
  - Overlay/inset images
  - Text annotation
@@ -66,6 +66,8 @@ Work remaining to be completed on this module:
 #include "magick.h"
 #include "defines.h"
 
+#if defined(HasWMF2)
+#endif /* HasWMF2 */
 #if defined(HasWMF)
 #include <wmfapi.h>
 
@@ -484,7 +486,7 @@ static void WmfCopyXpm(CSTRUCT *cstruct,
     buff[MaxTextExtent];
 
   /* image x,y width,height filename */
-  sprintf(buff, "image Copy %i,%i %i,%i XPM:%s\n",
+  sprintf(buff, "image Copy %i,%i %i,%i XPM:%.1024s\n",
           (int)dest_x,
           (int)dest_y,
           (int)dest_w,
@@ -1146,8 +1148,8 @@ static void WmfDrawText(CSTRUCT *cstruct, char *str, RECT *arect,
     strcpy(fontspec,"arial.ttf");
 
 
-  printf("facename=\"%s\", fontspec=\"%s\"\n", facename, fontspec);
-  sprintf(buff, "font %s\n", fontspec);
+  printf("facename=\"%.1024s\", fontspec=\"%.1024s\"\n", facename, fontspec);
+  sprintf(buff, "font %.1024s\n", fontspec);
   ExtendMVG(cstruct,buff);
 
   /* Compute gravity */
@@ -1189,7 +1191,7 @@ static void WmfDrawText(CSTRUCT *cstruct, char *str, RECT *arect,
     }
   if(*gravity!='\0')
     {
-      sprintf(buff, "gravity %s\n", gravity);
+      sprintf(buff, "gravity %.1024s\n", gravity);
       ExtendMVG(cstruct, buff);
     }
 
@@ -1211,7 +1213,7 @@ static void WmfDrawText(CSTRUCT *cstruct, char *str, RECT *arect,
 
   /* Render text */
   if(str!=NULL)
-    sprintf(buff, "text 0,0 \"%s\"\n",str);
+    sprintf(buff, "text 0,0 \"%.1024s\"\n",str);
   ExtendMVG(cstruct, buff);
 
   ExtendMVG(cstruct, "pop graphic-context\n");
@@ -1522,7 +1524,8 @@ static void WmfSetPenStyle(CSTRUCT *cstruct, LOGPEN *pen, DC *currentDC)
       /* Source XOR Dest */
       break;
     default:
-      break;
+      {
+      }
     }
 
   if (pen->lopnWidth <= 1)
@@ -1540,6 +1543,9 @@ static void WmfSetPenStyle(CSTRUCT *cstruct, LOGPEN *pen, DC *currentDC)
         case PS_ALTERNATE:
         case PS_USERSTYLE:
           break;
+        default:
+          {
+          }
         }
     }
 
@@ -1550,7 +1556,10 @@ static void WmfSetPenStyle(CSTRUCT *cstruct, LOGPEN *pen, DC *currentDC)
     case PS_ENDCAP_FLAT:
       break;
     case PS_ENDCAP_ROUND:
+      break;
     default:
+      {
+      }
     }
 
   switch(pen->lopnStyle & PS_JOIN_MASK)
@@ -1560,7 +1569,10 @@ static void WmfSetPenStyle(CSTRUCT *cstruct, LOGPEN *pen, DC *currentDC)
     case PS_JOIN_MITER:
       break;
     case PS_JOIN_ROUND:
+      break;
     default:
+      {
+      }
     }
 
   puts("WmfSetPenStyle() not implemented");
@@ -1590,7 +1602,7 @@ static Image *ReadWMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image=AllocateImage(image_info);
   GetExceptionInfo(exception);
 
-/*       printf("magick=%s\n", image_info->magick); */
+/*       printf("magick=%.1024s\n", image_info->magick); */
   /* Return WFM hatch images */
 /*   if(LocaleCompare(image_info->magick,"WMF") != 0) */
 /*     { */
@@ -1698,7 +1710,7 @@ static Image *ReadWMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 image_info->background_color.blue,
                 image_info->background_color.opacity);
       else
-        sprintf(clone_info->filename,"TILE:%s",image_info->texture);
+        sprintf(clone_info->filename,"TILE:%.1024s",image_info->texture);
       GetExceptionInfo(exception);
       DestroyImage(image);
       image = ReadImage( clone_info, exception );
@@ -1753,7 +1765,7 @@ static Image *ReadWMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   return image;
 }
-#endif
+#endif /* HasWMF */
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -1780,7 +1792,7 @@ static Image *ReadWMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 */
 ModuleExport void RegisterWMFImage(void)
 {
-#if defined(HasWMF)
+#if defined(HasWMF) || defined(HasWMF2)
   MagickInfo
     *entry;
 
@@ -1840,7 +1852,7 @@ ModuleExport void RegisterWMFImage(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   U n r e g i s t e r R G B I m a g e                                       %
+%   U n r e g i s t e r W M F I m a g e                                       %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -1856,7 +1868,7 @@ ModuleExport void RegisterWMFImage(void)
 */
 ModuleExport void UnregisterWMFImage(void)
 {
-#if defined(HasWMF)
+#if defined(HasWMF) || defined(HasWMF2)
   UnregisterMagickInfo("WMF");
 #endif
 }
