@@ -165,35 +165,35 @@ register IndexPacket *indexes;
            indexes=GetIndexes(image);
            for (x=0; x < ((int) image->columns-1); x+=2)
                  {
-                 index=(*p >> 6) & 0x3;
+                 index=ValidateColormapIndex(image,(*p >> 6) & 0x3);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-		 index=(*p >> 4) & 0x3;
+		 index=ValidateColormapIndex(image,(*p >> 4) & 0x3);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-		 index=(*p >> 2) & 0x3;
+		 index=ValidateColormapIndex(image,(*p >> 2) & 0x3);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-                 index=(*p) & 0x3;
+                 index=ValidateColormapIndex(image,(*p) & 0x3);
                  indexes[x+1]=index;
                  *q++=image->colormap[index];
                  p++;
                  }
            if ((image->columns % 4) != 0)
                  {
-                   index=(*p >> 6) & 0x3;
+                   index=ValidateColormapIndex(image,(*p >> 6) & 0x3);
                    indexes[x]=index;
                    *q++=image->colormap[index];
 		   if ((image->columns % 4) >= 1)
 
 		      {
-		      index=(*p >> 4) & 0x3;
+		      index=ValidateColormapIndex(image,(*p >> 4) & 0x3);
                       indexes[x]=index;
                       *q++=image->colormap[index];
 		      if ((image->columns % 4) >= 2)
 
 		        {
-		        index=(*p >> 2) & 0x3;
+		        index=ValidateColormapIndex(image,(*p >> 2) & 0x3);
                         indexes[x]=index;
                         *q++=image->colormap[index];
 		        }
@@ -216,17 +216,17 @@ register IndexPacket *indexes;
            indexes=GetIndexes(image);
            for (x=0; x < ((int) image->columns-1); x+=2)
                  {
-                 index=(*p >> 4) & 0xf;
+                 index=ValidateColormapIndex(image,(*p >> 4) & 0xf);
                  indexes[x]=index;
                  *q++=image->colormap[index];
-                 index=(*p) & 0xf;
+                 index=ValidateColormapIndex(image,(*p) & 0xf);
                  indexes[x+1]=index;
                  *q++=image->colormap[index];
                  p++;
                  }
            if ((image->columns % 2) != 0)
                  {
-                   index=(*p >> 4) & 0xf;
+                   index=ValidateColormapIndex(image,(*p >> 4) & 0xf);
                    indexes[x]=index;
                    *q++=image->colormap[index];
                    p++;
@@ -246,7 +246,7 @@ register IndexPacket *indexes;
 
 	   for (x=0; x < (int) image->columns; x++)
                 {
-                index=(*p++);
+                index=ValidateColormapIndex(image,*p++);
                 indexes[x]=index;
                 *q++=image->colormap[index];
                 }
@@ -278,7 +278,7 @@ register IndexPacket *indexes;
        }
 }
 
-#define InsertByte(b) {BImgBuff[x]=b;x++;if(x>=ldblk) {InsertRow(BImgBuff,y,image);x=0;y++;}}
+#define InsertByte(b) {BImgBuff[x]=b;x++;if((int)x>=ldblk) {InsertRow(BImgBuff,y,image);x=0;y++;}}
 static int UnpackWPGRaster(Image *image)
 {
 unsigned x,y,i;
@@ -294,7 +294,7 @@ long ldblk;
  BImgBuff=(unsigned char *) malloc(ldblk);
  if(BImgBuff==NULL) return(-2);
 
- while(y<image->rows)
+ while(y<(int) image->rows)
      {
      bbuf=ReadBlobByte(image);
 
@@ -310,17 +310,17 @@ long ldblk;
 	if(RunCount)	/* repeat next byte runcount * */
 		{
 		bbuf=ReadBlobByte(image);
-		for(i=0;i<RunCount;i++) InsertByte(bbuf);
+		for(i=0;i<(int) RunCount;i++) InsertByte(bbuf);
 		}
 	   else {	/* read next byte as RunCount; repeat 0xFF runcount* */
 		RunCount=ReadBlobByte(image);
-		for(i=0;i<RunCount;i++) InsertByte(0xFF);
+		for(i=0;i<(int) RunCount;i++) InsertByte(0xFF);
 		}
 	}
    else {
 	if(RunCount)   /* next runcount byte are readed directly */
 		{
-		for(i=0;i<RunCount;i++)
+		for(i=0;i < (int) RunCount;i++)
 			{
 			bbuf=ReadBlobByte(image);
 			InsertByte(bbuf);
@@ -332,7 +332,7 @@ long ldblk;
 		      free(BImgBuff);/* I do not know what to do here */
 		      return(-3);
 		      }
-		for(i=0;i<RunCount;i++)
+		for(i=0;i < (int) RunCount;i++)
 			{
 			x=0;
 			y++;    /* Here I need to duplicate previous row RUNCOUNT* */
@@ -358,6 +358,8 @@ unsigned x,y,i;
 unsigned char bbuf,RunCount;
 unsigned char *BImgBuff;
 long ldblk;
+unsigned char SampleBuffer[8];
+char SampleSize=1;
 
 
  x=0;
@@ -366,61 +368,60 @@ long ldblk;
  BImgBuff=(unsigned char *) malloc(ldblk);
  if(BImgBuff==NULL) return(-2);
 
- ReadBlobByte(image);
- ReadBlobByte(image);
-
- while(y<image->rows)
+ while(y<(int) image->rows)
      {
      bbuf=ReadBlobByte(image);
 
+     switch(bbuf)
+       {
+       case 0x7D:SampleSize=ReadBlobByte(image);	
+		 if(SampleSize>8) return(-2);
+		 if(SampleSize<1) return(-2);
+		 break;
+       case 0x7E:
+		 break;
+       case 0x7F:RunCount=ReadBlobByte(image);	
+		 for(i=0;i<SampleSize*((unsigned)RunCount+1);i++)
+			{
+			InsertRByte(0);
+			}
+		 break;
+       case 0xFD:
+		 break;
+       case 0xFE:
+		 break;
+       case 0xFF:RunCount=ReadBlobByte(image);
+		 for(i=0;i<SampleSize*((unsigned)RunCount+1);i++)
+			{
+			InsertRByte(0xFF);
+			}
+		 break;
+       default:
+	  RunCount=bbuf & 0x7F;
 
-     RunCount=bbuf & 0x7F;
-     if(bbuf & 0x80)
-	{
-	if(RunCount!=0x7F)	/* repeat next byte runcount */
-		{
-		bbuf=ReadBlobByte(image);
-		for(i=0;i<=RunCount;i++) InsertRByte(bbuf);
+	  if(bbuf & 0x80)
+		{	
+		for(i=0;i<(int) SampleSize;i++)
+			SampleBuffer[i]=ReadBlobByte(image);
+		for(i=0;i<=(unsigned)RunCount;i++)
+		    for(bbuf=0;bbuf<SampleSize;bbuf++)
+			InsertRByte(SampleBuffer[bbuf]);
 		}
-	   else {	/*read next byte as RunCount; repeat 0xFF runcount*/
-		RunCount=ReadBlobByte(image);
-		for(i=0;i<=RunCount;i++) InsertRByte(0xFF);
-		}
-	}
-   else {
-	if(RunCount!=0x7F)   /* next runcount byte are readed directly */
-		{
-		for(i=0;i<=RunCount;i++)
+	   else {
+		for(i=0;i<(int) SampleSize*((unsigned)RunCount+1);i++)
 			{
 			bbuf=ReadBlobByte(image);
 			InsertRByte(bbuf);
 			}
 		}
-	   else {
-		RunCount=ReadBlobByte(image);
-		if(x) {		/*read next byte as RunCount; repeat 0 runcount*/
-		      for(i=0;i<=RunCount;i++)
-				 InsertRByte(0);
-		      }
-		else for(i=0;i<=RunCount;i++) /* repeat previous line runcount*/
-			{
-			x=0;
-			y++;   /* Here I need to duplicate previous row RUNCOUNT* */
-			if(y<2) continue;
-			if(y>image->rows)
-				 {
-				 free(BImgBuff);
-				 return(-4);
-				 }
-			InsertRow(BImgBuff,image->rows-y-2,image);
-			}
-		}
-	}
-   }
+	  }
+
+     }
  free(BImgBuff);
  return(0);
 }
 
+
 static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
   long PS_Offset,long PS_Size)
 {
@@ -433,8 +434,6 @@ Image *image2;
 if ((clone_info=CloneImageInfo(image_info)) == NULL) return(image);
 TemporaryFilename((char *) clone_info->filename);
 
-/*printf("PS part %ld %ld %s\n",PS_Offset,PS_Size,clone_info->filename);*/
-
 if( (f=fopen(clone_info->filename,"wb"))==NULL) goto FINISH;
 SeekBlob(image,PS_Offset,SEEK_SET);
 while(PS_Size-->0)
@@ -516,12 +515,13 @@ typedef struct
 	unsigned char	RecType;
 	unsigned long   RecordLength;
 	}WPGRecord;
-typedef struct 
+typedef struct
 	{
-	unsigned char	RecLeader;
-	unsigned int    RecType;
+	unsigned char	Class;
+	unsigned char    RecType;
+	unsigned long   Extension;
 	unsigned long   RecordLength;
-	} WPG2Record;
+	}WPG2Record;
 typedef struct
 	{
 	unsigned int Width;
@@ -698,7 +698,7 @@ NoMemory:		ThrowReaderException(ResourceLimitWarning,"Memory allocation failed",
 		     }
 		 else {
 		      if(image->depth<24)
-			if( image->colors<(1<<image->depth) && image->depth!=24 )
+			if( (int) image->colors<(1<<image->depth) && image->depth!=24 )
 			    ReacquireMemory((void **) &image->colormap,(1<<image->depth)*sizeof(PixelPacket));
 		      }
 		      
@@ -742,9 +742,9 @@ DecompressionFailed: ThrowReaderException(ResourceLimitWarning,"Cannot decompres
        SeekBlob(image,Header.DataOffset,SEEK_SET);
        if(EOFBlob(image)) break;
 
-       Rec2.RecLeader=(i=ReadBlobByte(image));
-       if(i==EOF) break;
-       Rec2.RecType=ReadBlobLSBShort(image);
+       Rec2.Class=(i=ReadBlobByte(image)); if(i==EOF) break;
+       Rec2.RecType=(i=ReadBlobByte(image)); if(i==EOF) break;
+       Rd_WP_DWORD(image,&Rec2.Extension);
        Rd_WP_DWORD(image,&Rec2.RecordLength);
        if(EOFBlob(image)) break;
 
@@ -795,7 +795,7 @@ DecompressionFailed: ThrowReaderException(ResourceLimitWarning,"Cannot decompres
 		     }
 	     else {
 		  if(image->depth<24)
-		    if( image->colors<(1<<image->depth) && image->depth!=24 )
+		    if( (int) image->colors<(1<<image->depth) && image->depth!=24 )
 			 ReacquireMemory((void **) &image->colormap,(1<<image->depth)*sizeof(PixelPacket));
 		  }
 
@@ -807,7 +807,7 @@ DecompressionFailed: ThrowReaderException(ResourceLimitWarning,"Cannot decompres
 		   ldblk=((long)image->depth*image->columns+7)/8;
 		   if( (BImgBuff=(unsigned char *) malloc(ldblk))==NULL) goto NoMemory;
 
-		   for(i=0;i<image->rows;i++)
+		   for(i=0;i<(int) image->rows;i++)
 		      {
 		      ReadBlob(image,ldblk,(char *)BImgBuff);
 		      InsertRow(BImgBuff,i,image);
