@@ -13,6 +13,10 @@
 #ifndef _MAGICK_API_H
 #define _MAGICK_API_H
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #if defined(__cplusplus) || defined(c_plusplus)
 #define storage_class  c_class
 #else
@@ -37,7 +41,6 @@
 #    define MagickExport
 #    pragma message( "Compiling as simple library" ) 
 #  endif
-
 #if defined(_DLL) && !defined(_LIB)
 #  define ModuleExport  __declspec(dllexport)
 #  pragma message( "Module compiled as DLL" ) 
@@ -52,6 +55,7 @@
 #pragma warning(disable : 4244)
 #pragma warning(disable : 4142)
 #pragma warning(disable : 4800)
+#pragma warning(disable : 4786)
 
 #else
 # define MagickExport __declspec(dllexport)
@@ -64,15 +68,16 @@
 # define MagickGlobal
 #endif
 
-#define MaxTextExtent  1664
+#define MaxTextExtent  2053
+#define MagickSignature  0xabacadab
 
-#if !defined(vms) && !defined(WIN32)
-#if defined(HAVE_CONFIG_H)
+#if !defined(vms) && !defined(macintosh)
 #include "magick/config.h"
-#endif
 #include "magick/classify.h"
 #include "magick/image.h"
+#include "magick/colors.h"
 #include "magick/draw.h"
+#include "magick/fonts.h"
 #include "magick/gems.h"
 #include "magick/quantize.h"
 #include "magick/compress.h"
@@ -81,6 +86,7 @@
 #include "magick/blob.h"
 #include "magick/cache.h"
 #include "magick/cache_view.h"
+#include "magick/magic.h"
 #include "magick/delegates.h"
 #include "magick/timer.h"
 #include "magick/semaphore.h"
@@ -88,9 +94,12 @@
 #include "magick/error.h"
 #include "magick/version.h"
 #else
+#include "config.h"
 #include "classify.h"
 #include "image.h"
+#include "colors.h"
 #include "draw.h"
+#include "fonts.h"
 #include "gems.h"
 #include "quantize.h"
 #include "compress.h"
@@ -107,4 +116,9 @@
 #include "version.h"
 #endif
 
+
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif
