@@ -27,12 +27,15 @@ extern "C" {
    (strchr(text,'}') != (char *) NULL) || \
    (strchr(text,'[') != (char *) NULL) || \
    (strchr(text,']') != (char *) NULL))
-#if !defined(MagickConfigurePath)
-#define MagickConfigurePath  "/usr/local/share/ImageMagick/"
+#if !defined(MagickLibPath)
+#define MagickLibPath  "/usr/local/lib/ImageMagick/"
 #endif
 #if !defined(MagickModulesPath)
 #define MagickModulesPath  "/usr/local/lib/ImageMagick/modules/"
 #endif
+#if !defined(MagickSharePath)
+#define MagickSharePath  "/usr/local/share/ImageMagick/"
+#endif
 #define PreferencesDefaults  "~/."
 #define ProcessPendingEvents(text)
 #define ReadCommandlLine(argc,argv)
@@ -56,8 +59,9 @@ extern "C" {
    (strchr(text,'{') != (char *) NULL) || \
    (strchr(text,'}') != (char *) NULL))
 #define j1(x)  x
-#define MagickConfigurePath  "sys$login:"
+#define MagickLibPath  "sys$login:"
 #define MagickModulesPath  "sys$login:"
+#define MagickSharePath  "sys$login:"
 #define PreferencesDefaults  "decw$user_defaults:"
 #define ProcessPendingEvents(text)
 #define ReadCommandlLine(argc,argv)
@@ -81,8 +85,9 @@ extern "C" {
    (strchr(text,'[') != (char *) NULL) || \
    (strchr(text,']') != (char *) NULL))
 #define j1(x)  x
-#define MagickConfigurePath  ""
+#define MagickLibPath  ""
 #define MagickModulesPath  ""
+#define MagickSharePath  ""
 #define PreferencesDefaults  "~/."
 #define ReadCommandlLine(argc,argv)  argc=ccommand(argv); puts(MagickVersion);
 #if !defined(X11ConfigurePath)
@@ -109,8 +114,9 @@ extern "C" {
    (strchr(text,'[') != (char *) NULL) || \
    (strchr(text,']') != (char *) NULL))
 #define j1(x)  x
-#define MagickConfigurePath  "c:\\ImageMagick\\"
+#define MagickLibPath  "c:\\ImageMagick\\"
 #define MagickModulesPath  "c:\\ImageMagick\\"
+#define MagickSharePath  "c:\\ImageMagick\\"
 #define PreferencesDefaults  "~/."
 #define ProcessPendingEvents(text)
 #define ReadCommandlLine(argc,argv)
@@ -131,6 +137,15 @@ extern "C" {
   Define declarations.
 */
 #define AbsoluteValue(x)  ((x) < 0 ? -(x) : (x))
+#define AlphaComposite(p,alpha,q,beta) \
+  (q)->red=(Quantum) (((double) (MaxRGB-(alpha))*(p)->red+ \
+    (double) (alpha)*(MaxRGB-(beta))*(q)->red/MaxRGB)/MaxRGB+0.5); \
+  (q)->green=(Quantum) (((double) (MaxRGB-(alpha))*(p)->green+ \
+    (double) (alpha)*(MaxRGB-(beta))*(q)->green/MaxRGB)/MaxRGB+0.5); \
+  (q)->blue=(Quantum) (((double) (MaxRGB-(alpha))*(p)->blue+ \
+    (double) (alpha)*(MaxRGB-(beta))*(q)->blue/MaxRGB)/MaxRGB+0.5); \
+  (q)->opacity=(Quantum) (((double) (MaxRGB-(alpha))+ \
+    (double) (alpha)*(MaxRGB-(beta))/MaxRGB)/MaxRGB+0.5)
 #define CloseImage(image)  CloseBlob(image)
 #define ColorMatch(color,target,distance) \
   (((distance) == 0) ? \
@@ -146,24 +161,22 @@ extern "C" {
       (double) (distance*distance))
 #define Extent(string)  ((int) strlen(string))
 #define False  0
-#define DegreesToRadians(x) (M_PI*(x)/180.0)
+#define DegreesToRadians(x) (MagickPI*(x)/180.0)
 #define Intensity(color)  \
-  ((0.299*(color).red+0.587*(color).green+(0.114+MagickEpsilon)*(color).blue))
+  ((9798*(color).red+19235*(color).green+3735*(color).blue)/32768L)
 #define IsFaxImage(color) \
   (IsMonochromeImage(image) && ((image)->columns <= 2560))
 #define IsGray(color)  \
   (((color).red == (color).green) && ((color).green == (color).blue))
 #define MagickEpsilon  1.0e-12
+#define MagickPI  3.14159265358979323846264338327950288419716939937510
 #define Max(x,y)  (((x) > (y)) ? (x) : (y))
 #define MaxApplicationProfiles  16
 #define Min(x,y)  (((x) < (y)) ? (x) : (y))
-#if !defined(M_PI)
-#define M_PI  3.14159265358979323846
-#endif
 #define OpenImage(image_info,image,type)  OpenBlob(image,image,type)
 #define QuantumTick(i,span) \
   (((~((span)-i-1) & ((span)-i-2))+1) == ((span)-i-1))
-#define RadiansToDegrees(x) (180.0*(x)/M_PI)
+#define RadiansToDegrees(x) (180.0*(x)/MagickPI)
 #define RenderPostscriptText  "  Rendering postscript...  "
 #define ScaleColor5to8(x)  ((x) << 3)
 #define ScaleColor6to8(x)  ((x) << 2)
