@@ -62,19 +62,24 @@
 #include "defines.h"
 
 /*
-  Constant declaractions.
+  Define declarations.
 */
-const char
-  *DelegateFilename = "delegates.mgk";
+#define DelegateFilename  "delegates.mgk"
 
 /*
   Global declaractions.
 */
 static DelegateInfo
-  *delegates = (DelegateInfo *) NULL;
+  *delegate_list = (DelegateInfo *) NULL;
 
-static SemaphoreInfo *
-  delegate_semaphore = (SemaphoreInfo *) NULL;
+static SemaphoreInfo
+  *delegate_semaphore = (SemaphoreInfo *) NULL;
+
+/*
+  Forward declaractions.
+*/
+static unsigned int
+  ReadConfigurationFile(const char *);
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -100,7 +105,7 @@ static SemaphoreInfo *
 extern "C" {
 #endif
 
-MagickExport void DestroyDelegateInfo(void)
+static void DestroyDelegateInfo(void)
 {
   DelegateInfo
     *delegate;
@@ -108,17 +113,23 @@ MagickExport void DestroyDelegateInfo(void)
   register DelegateInfo
     *p;
 
-  AcquireSemaphore(delegate_semaphore);
-  for (p=delegates; p != (DelegateInfo *) NULL; )
+  AcquireSemaphore(&delegate_semaphore);
+  for (p=delegate_list; p != (DelegateInfo *) NULL; )
   {
+    if (p->filename != (char *) NULL)
+      LiberateMemory((void **) &p->filename);
+    if (p->decode != (char *) NULL)
+      LiberateMemory((void **) &p->decode);
+    if (p->encode != (char *) NULL)
+      LiberateMemory((void **) &p->encode);
     if (p->commands != (char *) NULL)
       LiberateMemory((void **) &p->commands);
     delegate=p;
     p=p->next;
     LiberateMemory((void **) &delegate);
   }
-  delegates=(DelegateInfo *) NULL;
-  LiberateSemaphore(delegate_semaphore);
+  delegate_list=(DelegateInfo *) NULL;
+  LiberateSemaphore(&delegate_semaphore);
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
@@ -137,72 +148,80 @@ MagickExport void DestroyDelegateInfo(void)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Method GetDelegateInfo returns any delegates associated with the specified
-%  tag.  True is returned if a delegate is found, otherwise False.
+%  tag.  
 %
 %  The format of the GetDelegateInfo method is:
 %
-%      unsigned int GetDelegateInfo(const char *decode_tag,
-%        const char *encode_tag,DelegateInfo *delegate_info)
+%      DelegateInfo *GetDelegateInfo(const char *decode,const char *encode,
+%        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o status: Method GetDelegateInfo returns True if a delegate is found,
-%      otherwise False.
+%    o delgate_info: Method GetDelegateInfo returns any delegates associated
+%      with the specified tag.  
 %
-%    o decode_tag: Specifies the decode delegate we are searching for as a
+%    o decode: Specifies the decode delegate we are searching for as a
 %      character string.
 %
-%    o encode_tag: Specifies the encode delegate we are searching for as a
+%    o encode: Specifies the encode delegate we are searching for as a
 %      character string.
 %
-%    o delegate_info:  A structure of type DelegateInfo.  On return this
-%      structure contains the delegate information for the specified
-%      tag.
+%    o exception: return any errors or warnings in this structure.
 %
 %
 */
-MagickExport unsigned int GetDelegateInfo(const char *decode_tag,
-  const char *encode_tag,DelegateInfo *delegate_info)
+MagickExport DelegateInfo *GetDelegateInfo(const char *decode,
+  const char *encode,ExceptionInfo *exception)
 {
-  DelegateInfo
-    *delegates;
+  register DelegateInfo
+    *p;
 
-  assert(delegate_info != (DelegateInfo *) NULL);
-  AcquireSemaphore(delegate_semaphore);
-  delegates=SetDelegateInfo((DelegateInfo *) NULL);
-  LiberateSemaphore(delegate_semaphore);
-  if (delegates == (DelegateInfo *) NULL)
-    MagickWarning(DelegateWarning,"no delegates configuration file found",
-      DelegateFilename);
+  AcquireSemaphore(&delegate_semaphore);
+  if (delegate_list == (DelegateInfo *) NULL)
+    {
+      unsigned int
+        status;
+
+      /*
+        Read delegates.
+      */
+      status=ReadConfigurationFile(DelegateFilename);
+      if (status == False)
+        ThrowException(exception,FileOpenWarning,
+          "Unable to read delegates configuration file",DelegateFilename);
+      atexit(DestroyDelegateInfo);
+    }
+  LiberateSemaphore(&delegate_semaphore);
+  if ((LocaleCompare(decode,"*") == 0) && (LocaleCompare(encode,"*") == 0))
+    return(delegate_list);
   /*
     Search for requested delegate.
   */
-  for ( ; delegates != (DelegateInfo *) NULL; delegates=delegates->next)
+  for (p=delegate_list; p != (DelegateInfo *) NULL; p=p->next)
   {
-    *delegate_info=(*delegates);
-    if (delegates->direction > 0)
+    if (p->mode > 0)
       {
-        if (LocaleCompare(delegates->decode_tag,decode_tag) == 0)
-          return(True);
+        if (LocaleCompare(p->decode,decode) == 0)
+          break;
         continue;
       }
-    if (delegates->direction < 0)
+    if (p->mode < 0)
       {
-        if (LocaleCompare(delegates->encode_tag,encode_tag) == 0)
-          return(True);
+        if (LocaleCompare(p->encode,encode) == 0)
+          break;
         continue;
       }
-    if (LocaleCompare(decode_tag,delegates->decode_tag) == 0)
-      if (LocaleCompare(encode_tag,delegates->encode_tag) == 0)
-        return(True);
-    if (LocaleCompare(decode_tag,"*") == 0)
-      if (LocaleCompare(encode_tag,delegates->encode_tag) == 0)
-        return(True);
-    if (LocaleCompare(decode_tag,delegates->decode_tag) == 0)
-      if (LocaleCompare(encode_tag,"*") == 0)
-        return(True);
+    if (LocaleCompare(decode,p->decode) == 0)
+      if (LocaleCompare(encode,p->encode) == 0)
+        break;
+    if (LocaleCompare(decode,"*") == 0)
+      if (LocaleCompare(encode,p->encode) == 0)
+        break;
+    if (LocaleCompare(decode,p->decode) == 0)
+      if (LocaleCompare(encode,"*") == 0)
+        break;
   }
-  return(False);
+  return(p);
 }
 
 /*
@@ -222,7 +241,7 @@ MagickExport unsigned int GetDelegateInfo(const char *decode_tag,
 %  The format of the GetDelegateCommand method is:
 %
 %      char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
-%        const char *decode_tag,const char *encode_tag)
+%        const char *decode,const char *encode)
 %
 %  A description of each parameter follows:
 %
@@ -233,23 +252,23 @@ MagickExport unsigned int GetDelegateInfo(const char *decode_tag,
 %
 %    o image: The address of a structure of type Image.
 %
-%    o decode_tag: Specifies the decode delegate we are searching for as a
+%    o decode: Specifies the decode delegate we are searching for as a
 %      character string.
 %
-%    o encode_tag: Specifies the encode delegate we are searching for as a
+%    o encode: Specifies the encode delegate we are searching for as a
 %      character string.
 %
 %
 */
 MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
-  const char *decode_tag,const char *encode_tag)
+  const char *decode,const char *encode)
 {
   char
     *command,
     **commands;
 
   DelegateInfo
-    delegate_info;
+    *delegate_info;
 
   register int
     i;
@@ -258,18 +277,19 @@ MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
   assert(image_info->signature == MagickSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  assert(decode_tag != (char *) NULL);
-  if (!GetDelegateInfo(decode_tag,encode_tag,&delegate_info))
+  assert(decode!= (char *) NULL);
+  delegate_info=GetDelegateInfo(decode,encode,&image->exception);
+  if (delegate_info == (DelegateInfo *) NULL)
     {
       ThrowException(&image->exception,MissingDelegateWarning,"no tag found",
-        decode_tag ? decode_tag : encode_tag);
+        decode ? decode : encode);
       return((char *) NULL);
     }
-  commands=StringToList(delegate_info.commands);
+  commands=StringToList(delegate_info->commands);
   if (commands == (char **) NULL)
     {
       ThrowException(&image->exception,ResourceLimitWarning,
-        "Memory allocation failed",decode_tag ? decode_tag : encode_tag);
+        "Memory allocation failed",decode ? decode : encode);
       return((char *) NULL);
     }
   command=TranslateText(image_info,image,commands[0]);
@@ -303,7 +323,7 @@ MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
 %  The format of the InvokeDelegate method is:
 %
 %      unsigned int InvokeDelegate(const ImageInfo *image_info,
-%        Image *image,const char *decode_tag,const char *encode_tag)
+%        Image *image,const char *decode,const char *encode)
 %
 %  A description of each parameter follows:
 %
@@ -314,7 +334,7 @@ MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
 %
 */
 MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
-  Image *image,const char *decode_tag,const char *encode_tag)
+  Image *image,const char *decode,const char *encode)
 {
   char
     *command,
@@ -322,7 +342,7 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
     filename[MaxTextExtent];
 
   DelegateInfo
-    delegate_info;
+    *delegate_info;
 
   register int
     i;
@@ -335,12 +355,13 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   (void) strcpy(filename,image->filename);
-  if (!GetDelegateInfo(decode_tag,encode_tag,&delegate_info))
+  delegate_info=GetDelegateInfo(decode,encode,&image->exception);
+  if (delegate_info == (DelegateInfo *) NULL)
     ThrowBinaryException(MissingDelegateWarning,"no tag found",
-      decode_tag ? decode_tag : encode_tag);
-  if (LocaleCompare(delegate_info.decode_tag,"YUV") == 0)
-    if ((LocaleCompare(delegate_info.encode_tag,"M2V") == 0) ||
-        (LocaleCompare(delegate_info.encode_tag,"MPG") == 0))
+      decode ? decode : encode);
+  if (LocaleCompare(delegate_info->decode,"YUV") == 0)
+    if ((LocaleCompare(delegate_info->encode,"M2V") == 0) ||
+        (LocaleCompare(delegate_info->encode,"MPG") == 0))
       {
         FILE
           *file;
@@ -352,11 +373,11 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
           Write parameter file (see mpeg2encode documentation for details).
         */
         CoalesceImages(image,&image->exception);
-        mpeg=LocaleCompare(delegate_info.encode_tag,"M2V") != 0;
+        mpeg=LocaleCompare(delegate_info->encode,"M2V") != 0;
         file=fopen(image_info->unique,"w");
         if (file == (FILE *) NULL)
           ThrowBinaryException(DelegateWarning,"delegate failed",
-            decode_tag ? decode_tag : encode_tag);
+            decode ? decode : encode);
         (void) fprintf(file,"MPEG\n");
         (void) fprintf(file,"%.1024s%%d\n",image->filename);
         (void) fprintf(file,"-\n");
@@ -419,9 +440,9 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
         (void) fclose(file);
         (void) strcat(image->filename,"%d.yuv");
       }
-  if (delegate_info.direction != 0)
-    if ((decode_tag && (*delegate_info.encode_tag != '\0')) ||
-        (encode_tag && (*delegate_info.decode_tag != '\0')))
+  if (delegate_info->mode != 0)
+    if ((decode && (delegate_info->encode != (char *) NULL)) ||
+        (encode && (delegate_info->decode != (char *) NULL)))
       {
         char
           filename[MaxTextExtent],
@@ -436,11 +457,11 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
         /*
           Delegate requires a particular image format.
         */
-        magick=TranslateText(image_info,image,decode_tag != (char *) NULL ?
-          delegate_info.encode_tag : delegate_info.decode_tag);
+        magick=TranslateText(image_info,image,decode != (char *) NULL ?
+          delegate_info->encode : delegate_info->decode);
         if (magick == (char *) NULL)
           ThrowBinaryException(DelegateWarning,"delegate failed",
-            decode_tag ? decode_tag : encode_tag);
+            decode ? decode : encode);
         LocaleUpper(magick);
         (void) strcpy((char *) image_info->magick,magick);
         (void) strcpy(image->magick,magick);
@@ -450,26 +471,26 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
         if (clone_info == (ImageInfo *) NULL)
           ThrowBinaryException(ResourceLimitWarning,"Memory allocation failed",
             (char *) NULL);
-        FormatString(clone_info->filename,"%.1024s:",delegate_info.decode_tag);
-        SetImageInfo(clone_info,True);
+        FormatString(clone_info->filename,"%.1024s:",delegate_info->decode);
+        SetImageInfo(clone_info,True,&image->exception);
         for (p=image; p != (Image *) NULL; p=p->next)
         {
-          FormatString(p->filename,"%.1024s:%.1024s",delegate_info.decode_tag,
+          FormatString(p->filename,"%.1024s:%.1024s",delegate_info->decode,
             filename);
           status=WriteImage(clone_info,p);
           if (status == False)
             ThrowBinaryException(DelegateWarning,"delegate failed",
-              decode_tag ? decode_tag : encode_tag);
+              decode ? decode : encode);
           if (clone_info->adjoin)
             break;
         }
         DestroyImageInfo(clone_info);
       }
   (void) strcpy(image->filename,filename);
-  commands=StringToList(delegate_info.commands);
+  commands=StringToList(delegate_info->commands);
   if (commands == (char **) NULL)
     ThrowBinaryException(ResourceLimitWarning,"Memory allocation failed",
-      decode_tag ? decode_tag : encode_tag);
+      decode ? decode : encode);
   command=(char *) NULL;
   status=True;
   for (i=0; commands[i] != (char *) NULL; i++)
@@ -481,6 +502,8 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
     /*
       Execute delegate.
     */
+    if (delegate_info->spawn)
+      ConcatenateString(&command," &");
     status=SystemCommand(image_info->verbose,command);
     LiberateMemory((void **) &command);
     if (status != False)
@@ -513,23 +536,22 @@ MagickExport unsigned int InvokeDelegate(const ImageInfo *image_info,
 %
 %  The format of the ListDelegateInfo method is:
 %
-%      unsigned int ListDelegateInfo(FILE *file)
+%      unsigned int ListDelegateInfo(FILE *file,ExceptionInfo *exception)
 %
 %  A description of each parameter follows.
 %
 %    o file:  An pointer to a FILE.
 %
+%    o exception: return any errors or warnings in this structure.
+%
 %
 */
-MagickExport unsigned int ListDelegateInfo(FILE *file)
+MagickExport unsigned int ListDelegateInfo(FILE *file,ExceptionInfo *exception)
 {
   char
     delegate[MaxTextExtent],
     tag[MaxTextExtent];
 
-  DelegateInfo
-    *delegates;
-
   register DelegateInfo
     *p;
 
@@ -538,22 +560,20 @@ MagickExport unsigned int ListDelegateInfo(FILE *file)
 
   if (file == (const FILE *) NULL)
     file=stdout;
-  AcquireSemaphore(delegate_semaphore);
-  delegates=SetDelegateInfo((DelegateInfo *) NULL);
-  LiberateSemaphore(delegate_semaphore);
-  if (delegates == (DelegateInfo *) NULL)
-    {
-      MagickWarning(DelegateWarning,"no delegates configuration file found",
-        DelegateFilename);
-      return(False);
-    }
-  (void) fprintf(file,"\nImageMagick uses these delegates to read or write "
-    "image formats it does not\ndirectly support:\n\n");
+  (void) fprintf(file,"ImageMagick defines these delegates to read orwrite "
+    "image formats it does not\ndirectly support.\n");
+  p=GetDelegateInfo("*","*",exception);
+  if (p == (DelegateInfo *) NULL)
+    return(False);
+  if (delegate_list->filename != (char *) NULL)
+    (void) fprintf(file,"\nFilename: %.1024s\n\n",delegate_list->filename);
   (void) fprintf(file,"Decode-Tag   Encode-Tag  Delegate\n");
-  (void) fprintf(file,"--------------------------------------------------------"
-    "-----------------\n");
-  for (p=delegates->next; p != (DelegateInfo *) NULL; p=p->next)
+  (void) fprintf(file,"-------------------------------------------------------"
+    "------------------------\n");
+  for (p=delegate_list; p != (DelegateInfo *) NULL; p=p->next)
   {
+    if (p->restrain)
+      continue;
     i=0;
     if (p->commands != (char *) NULL)
       for (i=0; !isspace((int) p->commands[i]); i++)
@@ -562,11 +582,11 @@ MagickExport unsigned int ListDelegateInfo(FILE *file)
     for (i=0; i < 10; i++)
       tag[i]=' ';
     tag[i]='\0';
-    if (p->encode_tag != (char *) NULL)
-      (void) strncpy(tag,p->encode_tag,Extent(p->encode_tag));
+    if (p->encode != (char *) NULL)
+      (void) strncpy(tag,p->encode,Extent(p->encode));
     (void) fprintf(file,"%10s%.1024s=%.1024s%.1024s  %s\n",
-      p->decode_tag ? p->decode_tag : "",p->direction <= 0 ? "<" : " ",
-      p->direction >= 0 ? ">" : " ",tag,delegate);
+      p->decode ? p->decode : "",p->mode <= 0 ? "<" : " ",
+      p->mode >= 0 ? ">" : " ",tag,delegate);
   }
   (void) fflush(file);
   return(True);
@@ -577,124 +597,202 @@ MagickExport unsigned int ListDelegateInfo(FILE *file)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+   R e a d D e l e g a t e s                                                 %
++   R e a d C o n f i g u r a t i o n F i l e                                 %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method ReadDelegates reads the delegates configuration file.
+%  Method ReadConfigurationFile reads the delegate configuration file which
+%  maps external delegates to a a particular image format.
 %
-%  The format of the ReadDelegates method is:
+%  The format of the ReadConfigurationFile method is:
 %
-%      unsigned int ReadDelegates(void)
+%      unsigned int ReadConfigurationFile(const char *filename)
 %
 %  A description of each parameter follows:
 %
-%    o status: Method ReadDelegates returns True if at least one delegate
-%      can be read otherwise False.
+%    o status: Method ReadConfigurationFile returns True if at least one delegate
+%      is defined otherwise False.
+%
+%    o basename:  The delegate configuration filename.
 %
 %
 */
-static unsigned int ReadDelegates(void)
+static unsigned int ReadConfigurationFile(const char *basename)
 {
   char
+    filename[MaxTextExtent],
+    keyword[MaxTextExtent],
     *path,
-    text[MaxTextExtent];
-
-  DelegateInfo
-    delegate_info;
+    value[MaxTextExtent];
 
   FILE
     *file;
 
+  int
+    c;
+
   register char
     *p;
 
-  unsigned int
-    number_delegates;
-
-  /*
-    Read delegate file.
-  */
-  number_delegates=0;
-  path=GetMagickConfigurePath(DelegateFilename);
+  path=GetMagickConfigurePath(basename);
   if (path == (char *) NULL)
     return(False);
-  file=fopen(path,"r");
+  FormatString(filename,"%.1024s",path);
   LiberateMemory((void **) &path);
+  file=fopen(filename,"r");
   if (file == (FILE *) NULL)
     return(False);
-  while (fgets(text,MaxTextExtent,file) != (char *) NULL)
+  for (c=fgetc(file); c != EOF; c=fgetc(file))
   {
-    if (*text == '#')
-      continue;
-    Strip(text);
-    if (*text == '\0')
-      continue;
-    *delegate_info.decode_tag='\0';
-    *delegate_info.encode_tag='\0';
-    for (p=text; (*p != '<') && (*p != '=') && (*p != '\0'); p++);
-    (void) strncpy(delegate_info.decode_tag,text,p-text);
-    delegate_info.decode_tag[p-text]='\0';
-    Strip(delegate_info.decode_tag);
-    delegate_info.direction=0;
-    if (*p == '<')
-      {
-        delegate_info.direction--;
-        p++;
-      }
-    if (*p == '=')
-      p++;
-    if (*p == '>')
-      {
-        delegate_info.direction++;
-        p++;
-      }
-    while (isspace((int) *p))
-      p++;
-    if (*p != '0')
-      (void) strcpy(delegate_info.encode_tag,p);
-    Strip(delegate_info.encode_tag);
-    delegate_info.commands=(char *) NULL;
-    while (fgets(text,MaxTextExtent,file) != (char *) NULL)
+    /*
+      Parse keyword.
+    */
+    while (isspace(c))
+      c=fgetc(file);
+    p=keyword;
+    do
     {
-      if (*text != '\t')
-        break;
-      Strip(text);
-      if (delegate_info.commands != (char *) NULL)
-        ReacquireMemory((void **) &delegate_info.commands,
-          (Extent(delegate_info.commands)+Extent(text)+3));
-      else
-        {
-          delegate_info.commands=(char *) AcquireMemory(Extent(text)+3);
-          if (delegate_info.commands != (char *) NULL)
-            *delegate_info.commands='\0';
-        }
-      if (delegate_info.commands == (char *) NULL)
-        break;
-      (void) strcat(delegate_info.commands,text);
-      if (delegate_info.commands[Extent(delegate_info.commands)-1] != '\\')
-        (void) strcat(delegate_info.commands,"\n");
-      else
-        delegate_info.commands[Extent(delegate_info.commands)-1]='\0';
-    }
-    if (delegate_info.commands == (char *) NULL)
-      MagickWarning(DelegateWarning,"no command for this delegate",
-        delegate_info.decode_tag);
-    else
+      if ((p-keyword) < (MaxTextExtent-1))
+        *p++=c;
+      c=fgetc(file);
+    } while ((c == '<') || isalnum(c) || (c == '!'));
+    *p='\0';
+    if (*keyword == '<')
       {
-        /*
-          Add delegate to the delegate list.
-        */
-        Strip(delegate_info.commands);
-        (void) SetDelegateInfo(&delegate_info);
-        number_delegates++;
-        LiberateMemory((void **) &delegate_info.commands);
+        if (LocaleCompare(keyword,"<!") == 0)
+          for (c=fgetc(file); (c != '>') && (c != EOF); c=fgetc(file));
+        if (LocaleCompare(keyword,"<delegate") == 0)
+          {
+            DelegateInfo
+              *delegate_info;
+
+            /*
+              Allocate memory for the delegate list.
+            */
+            delegate_info=(DelegateInfo *) AcquireMemory(sizeof(DelegateInfo));
+            if (delegate_info == (DelegateInfo *) NULL)
+              MagickError(ResourceLimitError,"Unable to allocate delegates",
+                "Memory allocation failed");
+            memset(delegate_info,0,sizeof(DelegateInfo));
+            if (delegate_list == (DelegateInfo *) NULL)
+              {
+                delegate_info->filename=AllocateString(filename);
+                delegate_list=delegate_info;
+              }
+            else
+              {
+                delegate_list->next=delegate_info;
+                delegate_info->previous=delegate_list;
+                delegate_list=delegate_list->next;
+              }
+          }
+        continue;
       }
+    while (isspace(c))
+      c=fgetc(file);
+    if (c != '=')
+      continue;
+    for (c=fgetc(file); isspace(c); c=fgetc(file));
+    if ((c != '"') && (c != '\''))
+      continue;
+    /*
+      Parse value.
+    */
+    p=value;
+    if (c == '"')
+      {
+        for (c=fgetc(file); (c != '"') && (c != EOF); c=fgetc(file))
+          if ((p-value) < (MaxTextExtent-1))
+            *p++=c;
+      }
+    else
+      for (c=fgetc(file); (c != '\'') && (c != EOF); c=fgetc(file))
+        if ((p-value) < (MaxTextExtent-1))
+          *p++=c;
+    *p='\0';
+    if (delegate_list == (DelegateInfo *) NULL)
+      continue;
+    switch (*keyword) 
+    {
+      case 'C':
+      case 'c':
+      {
+        if (LocaleCompare((char *) keyword,"command") == 0)
+          {
+            delegate_list->commands=AllocateString(value);
+            break;
+          }
+        break;
+      }
+      case 'D':
+      case 'd':
+      {
+        if (LocaleCompare((char *) keyword,"decode") == 0)
+          {
+            delegate_list->decode=AllocateString(value);
+            delegate_list->mode=1;
+            break;
+          }
+        break;
+      }
+      case 'E':
+      case 'e':
+      {
+        if (LocaleCompare((char *) keyword,"encode") == 0)
+          {
+            delegate_list->encode=AllocateString(value);
+            delegate_list->mode=(-1);
+            break;
+          }
+        break;
+      }
+      case 'M':
+      case 'm':
+      {
+        if (LocaleCompare((char *) keyword,"mode") == 0)
+          {
+            delegate_list->mode=1;
+            if (LocaleCompare(value,"bi") == 0)
+              delegate_list->mode=0;
+            else
+              if (LocaleCompare(value,"encode") == 0)
+                delegate_list->mode=(-1);
+            break;
+          }
+        break;
+      }
+      case 'R':
+      case 'r':
+      {
+        if (LocaleCompare((char *) keyword,"restrain") == 0)
+          {
+            delegate_list->restrain=LocaleCompare(value,"True") == 0;
+            break;
+          }
+        break;
+      }
+      case 'S':
+      case 's':
+      {
+        if (LocaleCompare((char *) keyword,"spawn") == 0)
+          {
+            delegate_list->spawn=LocaleCompare(value,"True") == 0;
+            break;
+          }
+        break;
+      }
+      default:
+        break;
+    }
   }
   (void) fclose(file);
-  return(number_delegates != 0);
+  if (delegate_list == (DelegateInfo *) NULL)
+    return(False);
+  while (delegate_list->previous != (DelegateInfo *) NULL)
+    delegate_list=delegate_list->previous;
+  return(True);
 }
 
 /*
@@ -734,24 +832,16 @@ MagickExport DelegateInfo *SetDelegateInfo(DelegateInfo *delegate_info)
   register DelegateInfo
     *p;
 
-  if (delegate_info == (DelegateInfo *) NULL)
-    {
-      /*
-        Read delegate configuration file.
-      */
-      (void) ReadDelegates();
-      atexit(DestroyDelegateInfo);
-      return(delegates);
-    }
   /*
     Initialize new delegate.
   */
+  assert(delegate_info != (DelegateInfo *) NULL);
   delegate=(DelegateInfo *) AcquireMemory(sizeof(DelegateInfo));
   if (delegate == (DelegateInfo *) NULL)
-    return(delegates);
-  (void) strcpy(delegate->decode_tag,delegate_info->decode_tag);
-  (void) strcpy(delegate->encode_tag,delegate_info->encode_tag);
-  delegate->direction=delegate_info->direction;
+    return(delegate_list);
+  (void) strcpy(delegate->decode,delegate_info->decode);
+  (void) strcpy(delegate->encode,delegate_info->encode);
+  delegate->mode=delegate_info->mode;
   delegate->commands=(char *) NULL;
   if (delegate_info->commands != (char *) NULL)
     {
@@ -761,23 +851,21 @@ MagickExport DelegateInfo *SetDelegateInfo(DelegateInfo *delegate_info)
       delegate->commands=(char *)
         AcquireMemory(Extent(delegate_info->commands)+1);
       if (delegate->commands == (char *) NULL)
-        return(delegates);
+        return(delegate_list);
       (void) strcpy(delegate->commands,delegate_info->commands);
     }
-  delegate->signature=MagickSignature;
   delegate->previous=(DelegateInfo *) NULL;
   delegate->next=(DelegateInfo *) NULL;
-  if (delegates == (DelegateInfo *) NULL)
+  if (delegate_list == (DelegateInfo *) NULL)
     {
-      delegates=delegate;
-      LiberateSemaphore(delegate_semaphore);
-      return(delegates);
+      delegate_list=delegate;
+      return(delegate_list);
     }
-  for (p=delegates; p != (DelegateInfo *) NULL; p=p->next)
+  for (p=delegate_list; p != (DelegateInfo *) NULL; p=p->next)
   {
-    if ((LocaleCompare(p->decode_tag,delegate_info->decode_tag) == 0) &&
-        (LocaleCompare(p->encode_tag,delegate_info->encode_tag) == 0) &&
-        (p->direction == delegate_info->direction))
+    if ((LocaleCompare(p->decode,delegate_info->decode) == 0) &&
+        (LocaleCompare(p->encode,delegate_info->encode) == 0) &&
+        (p->mode == delegate_info->mode))
       {
         /*
           Delegate overrides an existing one with the same tags.
@@ -785,7 +873,7 @@ MagickExport DelegateInfo *SetDelegateInfo(DelegateInfo *delegate_info)
         LiberateMemory((void **) &p->commands);
         p->commands=delegate->commands;
         LiberateMemory((void **) &delegate);
-        return(delegates);
+        return(delegate_list);
       }
     if (p->next == (DelegateInfo *) NULL)
       break;
@@ -795,5 +883,5 @@ MagickExport DelegateInfo *SetDelegateInfo(DelegateInfo *delegate_info)
   */
   delegate->previous=p;
   p->next=delegate;
-  return(delegates);
+  return(delegate_list);
 }
