@@ -14,12 +14,17 @@ extern "C" {
 typedef struct _DelegateInfo
 {
   char
-    decode_tag[MaxTextExtent],
-    encode_tag[MaxTextExtent],
+    *filename,
+    *decode,
+    *encode,
     *commands;
 
   int
-    direction;
+    mode;
+
+  unsigned int
+    restrain,
+    spawn;
 
   struct _DelegateInfo
     *previous,
@@ -27,21 +32,18 @@ typedef struct _DelegateInfo
 } DelegateInfo;
 
 /*
-  Exported delegate methods.
+  Magick delegate methods.
 */
-extern Export char
+extern MagickExport char
   *GetDelegateCommand(const ImageInfo *,Image *,const char *,const char *);
 
-extern Export DelegateInfo
+extern MagickExport DelegateInfo
+  *GetDelegateInfo(const char *,const char *,ExceptionInfo *exception),
   *SetDelegateInfo(DelegateInfo *);
 
-extern Export unsigned int
-  GetDelegateInfo(const char *,const char *,DelegateInfo *),
-  InvokeDelegate(const ImageInfo *,Image *,const char *,const char *);
-
-extern Export void
-  DestroyDelegateInfo(void),
-  ListDelegateInfo(FILE *);
+extern MagickExport unsigned int
+  InvokeDelegate(const ImageInfo *,Image *,const char *,const char *),
+  ListDelegateInfo(FILE *,ExceptionInfo *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
