@@ -325,13 +325,15 @@ const char
     "      Add",
     "      Subtract",
     "      Difference",
+    "      Multiply",
     "      Bumpmap",
-    "      Replace",
-    "      ReplaceRed",
-    "      ReplaceGreen",
-    "      ReplaceBlue",
-    "      ReplaceMatte",
-    "    Blend",
+    "      Copy",
+    "      CopyRed",
+    "      CopyGreen",
+    "      CopyBlue",
+    "      CopyOpacity",
+    "      Clear",
+    "    Dissolve",
     "    Displace",
     "    Help",
     "    Dismiss",
@@ -384,28 +386,30 @@ const char
     "         The result of abs(image - image window).  This is",
     "         useful for comparing two very similar images.",
     "",
+    "Multiply",
+    "         The result of image * image window.  This is",
+    "         useful for the creation of drop-shadows.",
+    "",
     "Bumpmap  The result of surface normals from image * image",
     "         window.",
     "",
-    "Replace  The resulting image is image window replaced with",
+    "Copy     The resulting image is image window replaced with",
     "         image.  Here the matte information is ignored.",
     "",
-    "ReplaceRed",
-    "         The red layer of the image window is replace with",
+    "CopyRed  The red layer of the image window is replace with",
     "         the red layer of the image.  The other layers are",
     "         untouched.",
     "",
-    "ReplaceGreen",
+    "CopyGreen",
     "         The green layer of the image window is replace with",
     "         the green layer of the image.  The other layers are",
     "         untouched.",
     "",
-    "ReplaceBlue",
-    "         The blue layer of the image window is replace with",
+    "CopyBlue The blue layer of the image window is replace with",
     "         the blue layer of the image.  The other layers are",
     "         untouched.",
     "",
-    "ReplaceMatte",
+    "CopyOpacity",
     "         The matte layer of the image window is replace with",
     "         the matte layer of the image.  The other layers are",
     "         untouched.",
@@ -419,7 +423,7 @@ const char
     "have a matte channel, it is initialized with 0 for any pixel",
     "matching in color to pixel location (0,0), otherwise 255.",
     "",
-    "If you choose Blend, the composite operator becomes Over.  The",
+    "If you choose Dissolve, the composite operator becomes Over.  The",
     "image matte channel percent transparency is initialized to factor.",
     "The image window is initialized to (100-factor). Where factor is the",
     "value you specify in the Dialog widget.",
@@ -1098,25 +1102,23 @@ const char
     "         The result of abs(image - image window).  This is",
     "         useful for comparing two very similar images.",
     "",
-    "Replace  The resulting image is image window replaced with",
+    "Copy     The resulting image is image window replaced with",
     "         image.  Here the matte information is ignored.",
     "",
-    "ReplaceRed",
-    "         The red layer of the image window is replace with",
+    "CopyRed  The red layer of the image window is replace with",
     "         the red layer of the image.  The other layers are",
     "         untouched.",
     "",
-    "ReplaceGreen",
+    "CopyGreen",
     "         The green layer of the image window is replace with",
     "         the green layer of the image.  The other layers are",
     "         untouched.",
     "",
-    "ReplaceBlue",
-    "         The blue layer of the image window is replace with",
+    "CopyBlue The blue layer of the image window is replace with",
     "         the blue layer of the image.  The other layers are",
     "         untouched.",
     "",
-    "ReplaceMatte",
+    "CopyOpacity",
     "         The matte layer of the image window is replace with",
     "         the matte layer of the image.  The other layers are",
     "         untouched.",
@@ -1398,7 +1400,7 @@ typedef enum
   ColorEditHelpCommand,
   ColorEditDismissCommand,
   CompositeOperatorsCommand,
-  CompositeBlendCommand,
+  CompositeDissolveCommand,
   CompositeDisplaceCommand,
   CompositeHelpCommand,
   CompositeDismissCommand,
