@@ -11,37 +11,64 @@ extern "C" {
 /*
   Typedef declarations.
 */
+typedef struct _EdgeInfo
+{
+  SegmentInfo
+    bounds;
+
+  double
+    scanline;
+
+  PointInfo
+    *points;
+
+  int
+    number_points,
+    direction,
+    ghostline,
+    highwater;
+} EdgeInfo;
+
+typedef struct _PolygonInfo
+{
+  EdgeInfo
+    *edges;
+
+  int
+    number_edges;
+} PolygonInfo;
+
 typedef struct _DrawInfo
 {
   char
-    *primitive;
+    *primitive,
+    *text,
+    *geometry;
 
-  AffineInfo
+  AffineMatrix
     affine;
 
-  double
-    angle;
-
   GravityType
     gravity;
 
-  PixelPacket
-    fill;
-
-  FillRule
-    fill_rule;
+  Quantum
+    opacity;
 
   Image
     *tile;
 
   PixelPacket
+    fill,
     stroke;
 
   unsigned int
     stroke_antialias;
 
   double
-    linewidth;
+    stroke_width;
+
+  FillRule
+    fill_rule;
 
   LineCap
     linecap;
@@ -51,14 +78,14 @@ typedef struct _DrawInfo
 
   unsigned int
     miterlimit,
-    *dash_pattern,
     dash_offset;
 
   DecorationType
     decorate;
 
   char
-    *font;
+    *font,
+    *density;
 
   unsigned int
     text_antialias;
@@ -70,13 +97,58 @@ typedef struct _DrawInfo
     box,
     border_color;
 
+  CompositeOperator
+    compose;
+
+  char
+    *server_name;
+
   unsigned int
-    verbose;
+    *dash_pattern;
+
+  PolygonInfo
+    clip_path;
+
+  unsigned int
+    debug;
 
   unsigned long
     signature;
 } DrawInfo;
 
+typedef struct _FontMetric
+{
+  PointInfo
+    pixels_per_em;
+    
+  int
+    ascent,
+    descent;
+    
+  unsigned int
+    width, 
+    height,
+    max_advance;
+} FontMetric;
+
+typedef struct _PrimitiveInfo
+{
+  PointInfo
+    point;
+
+  PrimitiveType
+    primitive;
+
+  unsigned int
+    coordinates;
+
+  PaintMethod
+    method;
+
+  char
+    *text;
+} PrimitiveInfo;
+
 /*
   Method declarations.
 */
@@ -84,9 +156,11 @@ extern MagickExport DrawInfo
   *CloneDrawInfo(const ImageInfo *,const DrawInfo *);
 
 extern MagickExport unsigned int
+  AnnotateImage(Image *,const DrawInfo *),
   ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const int x,
     const int y,const PaintMethod),
   DrawImage(Image *,const DrawInfo *),
+  GetFontMetrics(Image *,const DrawInfo *,FontMetric *),
   MatteFloodfillImage(Image *,const PixelPacket,const unsigned int,const int x,
     const int y,const PaintMethod);
 
