@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright (C) 2000 ImageMagick Studio, a non-profit organization dedicated %
+%  Copyright (C) 2001 ImageMagick Studio, a non-profit organization dedicated %
 %  to making software imaging solutions freely available.                     %
 %                                                                             %
 %  Permission is hereby granted, free of charge, to any person obtaining a    %
@@ -442,7 +442,7 @@ MagickExport unsigned int GammaImage(Image *image,const char *gamma)
     }
   }
   if (image->gamma != 0.0)
-    image->gamma*=(red_gamma+green_gamma+blue_gamma)/3.0;
+    image->gamma*=(red_gamma+green_gamma+blue_gamma+opacity_gamma)/4.0;
   LiberateMemory((void **) &gamma_map);
   return(True);
 }
@@ -471,7 +471,7 @@ MagickExport unsigned int GammaImage(Image *image,const char *gamma)
 %
 %    o modulate: A character string indicating the percent change in brightness,
 %      saturation, and hue in floating point notation separated by commas
-%      (e.g. 10.1,0.0,3.1).
+%      (e.g. 110.1,100.0,83.1).
 %
 %
 */
