@@ -61,301 +61,6 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   A l p h a C o m p o s i t e                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  Method AlphaComposite implements the alpha compositing rules for combining
-%  source and destination pixels to achieve blending and transparency effects
-%  with graphics and images. The rules implemented by this class are a subset
-%  of the Porter-Duff rules described in T. Porter and T. Duff, "Compositing
-%  Digital Images", SIGGRAPH 84, 253-259.
-%
-%  The format of the AlphaComposite method is:
-%
-%      PixelPacket AlphaComposite(const CompositeOperator compose,
-%        const PixelPacket *p,const double alpha,const PixelPacket *q,
-%        const double beta)
-%
-%  A description of each parameter follows:
-%
-%    o color: method AlphaComposite returns the color resulting from the
-%      compositing operation.
-%
-%    o compose: specifies an image composite operator.
-%
-%    o p: the source pixel.
-%
-%    o alpha: alpha component of the source pixel.
-%
-%    o q: the destination pixel.
-%
-%    o beta: alpha component of the destination pixel.
-%
-%
-*/
-MagickExport PixelPacket AlphaComposite(const CompositeOperator compose,
-  const PixelPacket *p,const double alpha,const PixelPacket *q,
-  const double beta)
-{
-  PixelPacket
-    color;
-
-  switch (compose)
-  {
-    case OverCompositeOp:
-    default:
-    {
-      switch ((int) alpha)
-      {
-        case TransparentOpacity:
-        {
-          color=(*q);
-          color.opacity=beta;
-          return(color);
-        }
-        case OpaqueOpacity:
-        {
-          color=(*p);
-          color.opacity=alpha;
-          return(color);
-        }
-        default:
-        {
-          color.red=(Quantum) (((MaxRGB-alpha)*p->red+
-            alpha/MaxRGB*(MaxRGB-beta)*q->red)/MaxRGB);
-          color.green=(Quantum) (((MaxRGB-alpha)*p->green+
-            alpha/MaxRGB*(MaxRGB-beta)*q->green)/MaxRGB);
-          color.blue=(Quantum) (((MaxRGB-alpha)*p->blue+
-            alpha/MaxRGB*(MaxRGB-beta)*q->blue)/MaxRGB);
-          color.opacity=(Quantum) (alpha*beta/MaxRGB);
-          return(color);
-        }
-      }
-      break;
-    }
-    case InCompositeOp:
-    {
-      color.red=(Quantum) ((MaxRGB-alpha)/MaxRGB*p->red*(MaxRGB-beta)/MaxRGB);
-      color.green=(Quantum)
-        ((MaxRGB-alpha)/MaxRGB*p->green*(MaxRGB-beta)/MaxRGB);
-      color.blue=(Quantum) ((MaxRGB-alpha)/MaxRGB*p->blue*(MaxRGB-beta)/MaxRGB);
-      color.opacity=(Quantum)
-        ((MaxRGB-alpha)/MaxRGB*alpha*(MaxRGB-beta)/MaxRGB);
-      return(color);
-    }
-    case OutCompositeOp:
-    {
-      color.red=(Quantum) ((MaxRGB-alpha)/MaxRGB*p->red*beta/MaxRGB);
-      color.green=(Quantum) ((MaxRGB-alpha)/MaxRGB*p->green*beta/MaxRGB);
-      color.blue=(Quantum) ((MaxRGB-alpha)/MaxRGB*p->blue*beta/MaxRGB);
-      color.opacity=(Quantum) ((MaxRGB-alpha)/MaxRGB*alpha*beta/MaxRGB);
-      return(color);
-    }
-    case AtopCompositeOp:
-    {
-      double
-        blue,
-        green,
-        opacity,
-        red;
-
-      red=((MaxRGB-alpha)/MaxRGB*p->red*(MaxRGB-beta)+
-        (MaxRGB-beta)/MaxRGB*q->red*alpha)/MaxRGB;
-      color.red=(Quantum) (red > MaxRGB ? MaxRGB : red);
-      green=((MaxRGB-alpha)/MaxRGB*p->green*(MaxRGB-beta)+
-        (MaxRGB-beta)/MaxRGB*q->green*alpha)/MaxRGB;
-      color.green=(Quantum) (green > MaxRGB ? MaxRGB : green);
-      blue=((MaxRGB-alpha)/MaxRGB*p->blue*(MaxRGB-beta)+
-        (MaxRGB-beta)/MaxRGB*q->blue*alpha)/MaxRGB;
-      color.blue=(Quantum) (blue > MaxRGB ? MaxRGB : blue);
-      opacity=((MaxRGB-alpha)/MaxRGB*alpha*(MaxRGB-beta)+
-        (MaxRGB-beta)/MaxRGB*beta*alpha)/MaxRGB;
-      color.opacity=(Quantum) (opacity > MaxRGB ? MaxRGB : opacity);
-      return(color);
-    }
-    case XorCompositeOp:
-    {
-      double
-        blue,
-        green,
-        opacity,
-        red;
-
-      red=((MaxRGB-alpha)/MaxRGB*p->red*beta+
-        (MaxRGB-beta)/MaxRGB*q->red*alpha)/MaxRGB;
-      color.red=(Quantum) (red > MaxRGB ? MaxRGB : red);
-      green=((MaxRGB-alpha)/MaxRGB*p->green*beta+
-        (MaxRGB-beta)/MaxRGB*q->green*alpha)/MaxRGB;
-      color.green=(Quantum) (green > MaxRGB ? MaxRGB : green);
-      blue=((MaxRGB-alpha)/MaxRGB*p->blue*beta+
-        (MaxRGB-beta)/MaxRGB*q->blue*alpha)/MaxRGB;
-      color.blue=(Quantum) (blue > MaxRGB ? MaxRGB : blue);
-      opacity=((MaxRGB-alpha)/MaxRGB*alpha*beta+
-        (MaxRGB-beta)/MaxRGB*beta*alpha)/MaxRGB;
-      color.opacity=(Quantum) (opacity > MaxRGB ? MaxRGB : opacity);
-      return(color);
-    }
-    case PlusCompositeOp:
-    {
-      double
-        blue,
-        green,
-        opacity,
-        red;
-
-      red=((MaxRGB-alpha)*p->red+(MaxRGB-beta)*q->red)/MaxRGB;
-      color.red=(Quantum) (red > MaxRGB ? MaxRGB : red);
-      green=((MaxRGB-alpha)*p->green+(MaxRGB-beta)*q->green)/MaxRGB;
-      color.green=(Quantum) (green > MaxRGB ? MaxRGB : green);
-      blue=((MaxRGB-alpha)*p->blue+(MaxRGB-beta)*q->blue)/MaxRGB;
-      color.blue=(Quantum) (blue > MaxRGB ? MaxRGB : blue);
-      opacity=((MaxRGB-alpha)*alpha+(MaxRGB-beta)*beta)/MaxRGB;
-      color.opacity=(Quantum) (opacity > MaxRGB ? MaxRGB : opacity);
-      return(color);
-    }
-    case MinusCompositeOp:
-    {
-      double
-        blue,
-        green,
-        opacity,
-        red;
-
-      red=((MaxRGB-alpha)*p->red-(MaxRGB-beta)*q->red)/MaxRGB;
-      color.red=(Quantum) (red < 0 ? 0 : red);
-      green=((MaxRGB-alpha)*p->green-(MaxRGB-beta)*q->green)/MaxRGB;
-      color.green=(Quantum) (green < 0 ? 0 : green);
-      blue=((MaxRGB-alpha)*p->blue-(MaxRGB-beta)*q->blue)/MaxRGB;
-      color.blue=(Quantum) (blue < 0 ? 0 : blue);
-      opacity=((MaxRGB-alpha)*p->opacity-(MaxRGB-beta)*q->opacity)/MaxRGB;
-      color.opacity=(Quantum) (opacity < 0 ? 0 : opacity);
-      return(color);
-    }
-    case AddCompositeOp:
-    {
-      double
-        blue,
-        green,
-        opacity,
-        red;
-
-      red=p->red+q->red;
-      color.red=(Quantum) (red > MaxRGB ? red-=MaxRGB : red);
-      green=p->green+q->green;
-      color.green=(Quantum) (green > MaxRGB ? green-=MaxRGB : green);
-      blue=p->blue+q->blue;
-      color.blue=(Quantum) (blue > MaxRGB ? blue-=MaxRGB : blue);
-      opacity=alpha+beta;
-      color.opacity=(Quantum) (opacity > MaxRGB ? opacity-=MaxRGB : opacity);
-      return(color);
-    }
-    case SubtractCompositeOp:
-    {
-      double
-        blue,
-        green,
-        opacity,
-        red;
-
-      red=p->red-q->red;
-      color.red=(Quantum) (red < 0 ? red+=MaxRGB : red);
-      green=p->green-q->green;
-      color.green=(Quantum) (green < 0 ? green+=MaxRGB : green);
-      blue=p->blue-q->blue;
-      color.blue=(Quantum) (blue < 0 ? blue+=MaxRGB : blue);
-      opacity=alpha-beta;
-      color.opacity=(Quantum) (opacity < 0 ? opacity+=MaxRGB : opacity);
-      return(color);
-    }
-    case MultiplyCompositeOp:
-    {
-      color.red=(unsigned long) (p->red*q->red/MaxRGB);
-      color.green=(unsigned long) (p->red*q->red/MaxRGB);
-      color.blue=(unsigned long) (p->red*q->red/MaxRGB);
-      color.opacity=(unsigned long) (p->red*q->red/MaxRGB);
-      return(color);
-    }
-    case DifferenceCompositeOp:
-    {
-      color.red=AbsoluteValue((int) p->red-(int) q->red);
-      color.green=AbsoluteValue((int) p->green-(int) q->green);
-      color.blue=AbsoluteValue((int) p->blue-(int) q->blue);
-      color.opacity=(Quantum) fabs(alpha-beta);
-      return(color);
-    }
-    case BumpmapCompositeOp:
-    {
-      color.red=(unsigned long) ((Intensity(*p)*q->red)/MaxRGB);
-      color.green=(unsigned long) ((Intensity(*p)*q->green)/MaxRGB);
-      color.blue=(unsigned long) ((Intensity(*p)*q->blue)/MaxRGB);
-      color.opacity=(unsigned long) ((Intensity(*p)*beta)/MaxRGB);
-      return(color);
-    }
-    case CopyCompositeOp:
-    {
-      color=(*p);
-      return(color);
-    }
-    case CopyRedCompositeOp:
-    {
-      color=(*q);
-      color.red=p->red;
-      return(color);
-    }
-    case CopyGreenCompositeOp:
-    {
-      color=(*q);
-      color.green=p->green;
-      return(color);
-    }
-    case CopyBlueCompositeOp:
-    {
-      color=(*q);
-      color.blue=p->blue;
-      return(color);
-    }
-    case CopyOpacityCompositeOp:
-    {
-      color=(*q);
-      color.opacity=alpha;
-      return(color);
-    }
-    case ClearCompositeOp:
-    {
-      color.red=0;
-      color.green=0;
-      color.blue=0;
-      color.opacity=0;
-      return(color);
-    }
-    case DissolveCompositeOp:
-    {
-      color.red=(unsigned long)
-        (((MaxRGB-alpha)*p->red+(MaxRGB-beta)*q->red)/MaxRGB);
-      color.green=(unsigned long)
-        (((MaxRGB-alpha)*p->green+(MaxRGB-beta)*q->green)/MaxRGB);
-      color.blue=(unsigned long)
-        (((MaxRGB-alpha)*p->blue+(MaxRGB-beta)*q->blue)/MaxRGB);
-      color.opacity=(unsigned long)
-        (((MaxRGB-alpha)*alpha+(MaxRGB-beta)*beta)/MaxRGB);
-      return(color);
-    }
-    case DisplaceCompositeOp:
-    {
-      color=(*p);
-      return(color);
-    }
-  }
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   C o n s t r a s t                                                         %
 %                                                                             %
 %                                                                             %
