@@ -18,7 +18,7 @@
 %                                September 1996                               %
 %                                                                             %
 %                                                                             %
-%  Copyright (C) 2000 ImageMagick Studio, a non-profit organization dedicated %
+%  Copyright (C) 2001 ImageMagick Studio, a non-profit organization dedicated %
 %  to making software imaging solutions freely available.                     %
 %                                                                             %
 %  Permission is hereby granted, free of charge, to any person obtaining a    %
@@ -48,8 +48,8 @@
 %
 %  The directory methods are strongly based on similar methods written
 %  by Steve Summit, scs@eskimo.com.  The Ghostscript launch code is strongly
-%  based on Dave Schooley's Mac Gnuplot and provided by
-%  schindall@wave14i.nrl.navy.mil.  Mac-centric improvements provided by
+%  based on Dave Schooley's Mac Gnuplot and contributed by
+%  schindall@wave14i.nrl.navy.mil.  Mac-centric improvements contributed by
 %  leonardr@digapp.com.
 %
 %
@@ -234,11 +234,7 @@ static short BottleneckTest(PicHandle picture,CodecType *codec,int *depth,
   bottlenecks.polyProc=NewQDPolyProc(&PolyMethod);
   bottlenecks.rgnProc=NewQDRgnProc(&RegionMethod);
   bottlenecks.bitsProc=NewQDBitsProc(&BitsMethod);
-#if GENERATINGCFM
-  bottlenecks.newProc1=NewStdPixProc(&StandardPixmap);
-#else
-  bottlenecks.newProc1=(UniversalProcPtr) StandardPixmap;
-#endif
+  bottlenecks.newProc1=(RoutineDescriptor *) NewStdPixProc(&StandardPixmap);
   /*
     Install our custom bottlenecks to intercept any compressed images.
   */
@@ -258,7 +254,6 @@ static short BottleneckTest(PicHandle picture,CodecType *codec,int *depth,
       *depth=(**image_description).depth;
       *colormap_id=(**image_description).clutID;
     }
-#if GENERATINGCFM
   DisposeRoutineDescriptor(bottlenecks.textProc);
   DisposeRoutineDescriptor(bottlenecks.lineProc);
   DisposeRoutineDescriptor(bottlenecks.rectProc);
@@ -269,7 +264,6 @@ static short BottleneckTest(PicHandle picture,CodecType *codec,int *depth,
   DisposeRoutineDescriptor(bottlenecks.rgnProc);
   DisposeRoutineDescriptor(bottlenecks.bitsProc);
   DisposeRoutineDescriptor(bottlenecks.newProc1);
-#endif
   return(0);
 }
 
@@ -375,40 +369,76 @@ MagickExport void pascal FilenameToFSSpec(const char *filename,FSSpec *fsspec)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   I m a g e F o r m a t C o n f l i c t                                     %
+%   I s M a g i c k C o n f l i c t                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method ImageFormatConflict returns true if the image format conflicts with
+%  Method MACIsMagickConflict returns true if the image format conflicts with
 %  a logical drive (.e.g. X:).
 %
 %  Contributed by Mark Gavin of Digital Applications, Inc.
 %
-%  The format of the ImageFormatConflict method is:
+%  The format of the MACIsMagickConflict method is:
 %
-%      status=ImageFormatConflict(magick)
+%      status=MACIsMagickConflict(magick)
 %
 %  A description of each parameter follows:
 %
-%    o status: Method ImageFormatConflict returns true if the image format
+%    o status: Method MACIsMagickConflict returns true if the image format
 %      conflicts with a logical drive.
 %
 %    o magick: Specifies the image format.
 %
 %
 */
-MagickExport int ImageFormatConflict(const char *magick)
+
+static OSErr HGetVInfo(short volume_index,StringPtr volume_name,short *volume,
+  unsigned long *free_bytes,unsigned long *total_bytes)
 {
-  long
+  HParamBlockRec
+    pb;
+
+  OSErr
+    result;
+  
+  unsigned long
+    blocksize;
+
+  unsigned short
+    allocation_blocks,
+    free_blocks;
+
+  /*
+    Use the File Manager to get the real vRefNum.
+  */
+  pb.volumeParam.ioVRefNum=0;
+  pb.volumeParam.ioNamePtr=volume_name;
+  pb.volumeParam.ioVolIndex=volume_index;
+  result=PBHGetVInfoSync(&pb);
+  if (result != noErr)
+    return(result);
+  *volume=pb.volumeParam.ioVRefNum;
+  blocksize=(unsigned long) pb.volumeParam.ioVAlBlkSiz;
+  allocation_blocks=(unsigned short) pb.volumeParam.ioVNmAlBlks;
+  free_blocks=(unsigned short) pb.volumeParam.ioVFrBlk;
+  *free_bytes=free_blocks*blocksize;
+  *total_bytes=allocation_blocks*blocksize;
+  return(result);
+}
+ 
+MagickExport int MACIsMagickConflict(const char *magick)
+{
+  unsigned long
+    free_bytes,
     number_bytes;
 
   OSErr
-    status,
-    volume;
+    status;
 
   short
+    volume,
     index;
 
   Str255
@@ -416,12 +446,12 @@ MagickExport int ImageFormatConflict(const char *magick)
 
   StringPtr
     p;
-
+  
   assert(magick != (char *) NULL);
   p=(StringPtr) &volume_name;
   for (index=(-1); ; index--)
   {
-    status=GetVInfo(index,p,&volume,&number_bytes);
+    status=HGetVInfo(index,p,&volume,&free_bytes,&number_bytes);
     if (status)
       return(False);
     if (LocaleCompare(p2cstr(p),magick) == 0)
@@ -441,47 +471,47 @@ MagickExport int ImageFormatConflict(const char *magick)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method MACErrorHandler displays an error message and then terminates
+%  Method MACErrorHandler displays an error reason and then terminates
 %  the program.
 %
 %  The format of the MACErrorHandler method is:
 %
-%      void MACErrorHandler(const ExceptionType error,const char *message,
-%        const char *qualifier)
+%      void MACErrorHandler(const ExceptionType error,const char *reason,
+%        const char *description)
 %
 %  A description of each parameter follows:
 %
 %    o exception: Specifies the numeric error category.
 %
-%    o message: Specifies the message to display before terminating the
+%    o reason: Specifies the reason to display before terminating the
 %      program.
 %
-%    o qualifier: Specifies any qualifier to the message.
+%    o description: Specifies any description to the reason.
 %
 %
 */
-MagickExport void MACErrorHandler(const ExceptionType error,const char *message,
-  const char *qualifier)
+MagickExport void MACErrorHandler(const ExceptionType error,const char *reason,
+  const char *description)
 {
   char
     buffer[3*MaxTextExtent];
 
-  if (message == (char *) NULL)
+  if (reason == (char *) NULL)
     Exit(0);
-  if ((qualifier != (char *) NULL) && errno)
+  if ((description != (char *) NULL) && errno)
     FormatString(buffer,"%.1024s: %.1024s (%.1024s) [%.1024s].\n",
-      SetClientName((char *) NULL),message,qualifier,strerror(errno));
+      SetClientName((char *) NULL),reason,description,strerror(errno));
   else
-    if (qualifier != (char *) NULL)
+    if (description != (char *) NULL)
       FormatString(buffer,"%.1024s: %.1024s (%.1024s).\n",
-        SetClientName((char *) NULL),message,qualifier);
+        SetClientName((char *) NULL),reason,description);
     else
       if (errno)
         FormatString(buffer,"%.1024s: %.1024s [%.1024s].\n",
-          SetClientName((char *) NULL),message,strerror(errno));
+          SetClientName((char *) NULL),reason,strerror(errno));
       else
         FormatString(buffer,"%.1024s: %.1024s.\n",SetClientName((char *) NULL),
-          message);
+          reason);
   puts(buffer);
   Exit(0);
 }
@@ -776,38 +806,38 @@ MagickExport int MACSystemCommand(const char * command)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method MACWarningHandler displays a warning message.
+%  Method MACWarningHandler displays a warning reason.
 %
 %  The format of the MACWarningHandler method is:
 %
-+      void MACWarningHandler(const ExceptionType warning,const char *message,
-%        const char *qualifier)
++      void MACWarningHandler(const ExceptionType warning,const char *reason,
+%        const char *description)
 %
 %  A description of each parameter follows:
 %
 %    o warning: Specifies the numeric warning category.
 %
-%    o message: Specifies the message to display before terminating the
+%    o reason: Specifies the reason to display before terminating the
 %      program.
 %
-%    o qualifier: Specifies any qualifier to the message.
+%    o description: Specifies any description to the reason.
 %
 %
 */
 MagickExport void MACWarningHandler(const ExceptionType warning,
-  const char *message,const char *qualifier)
+  const char *reason,const char *description)
 {
   char
     buffer[1664];
 
-  if (message == (char *) NULL)
+  if (reason == (char *) NULL)
     return;
-  if (qualifier == (char *) NULL)
+  if (description == (char *) NULL)
     FormatString(buffer,"%.1024s: %.1024s.\n",
-      SetClientName((char *) NULL),message);
+      SetClientName((char *) NULL),reason);
   else
     FormatString(buffer,"%.1024s: %.1024s (%.1024s).\n",
-      SetClientName((char *) NULL),message,qualifier);
+      SetClientName((char *) NULL),reason,description);
   puts(buffer);
 }
 
@@ -835,7 +865,7 @@ MagickExport void MACWarningHandler(const ExceptionType warning,
 %
 %
 */
-MagickExport DIR *opendir(char *path)
+MagickExport DIR *opendir(const char *path)
 {
   char
     pathname[1664];
@@ -1083,7 +1113,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
   GetGWorld(&port,&device);
   theErr=NewGWorld(&graphic_world,0,&(**picture_handle).picFrame,nil,nil,
     useTempMem | keepLocal);
-  if (theErr != noErr && graphic_world == nil)
+  if ((theErr != noErr) && (graphic_world == nil))
     {
       DisposeHandle((Handle) picture_handle);
       ThrowReaderException(ResourceLimitWarning,"Unable to allocate memory",
@@ -1160,7 +1190,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
   SetRect(&rectangle,0,0,image->columns,image->rows);
   (void) UpdateGWorld(&graphic_world,depth,&rectangle,
     picture_info.theColorTable,nil,0);
-  LockPixels(graphic_world->portPixMap);
+  LockPixels(GetGWorldPixMap(graphic_world));  /*->portPixMap); */
   EraseRect(&rectangle);
   DrawPicture(picture_handle,&rectangle);
   if ((depth <= 8) && (colormap_id == -1))
@@ -1193,7 +1223,7 @@ MagickExport Image *ReadPICTImage(const ImageInfo *image_info,
     if (QuantumTick(y,image->rows))
       MagickMonitor(LoadImageText,y,image->rows);
   }
-  UnlockPixels(graphic_world->portPixMap);
+  UnlockPixels(GetGWorldPixMap(graphic_world));
   SetGWorld(port,device);
   if (picture_info.theColorTable != nil)
     DisposeHandle((Handle) picture_info.theColorTable);
@@ -1355,18 +1385,22 @@ MagickExport void seekdir(DIR *entry,long position)
 MagickExport void SetApplicationType(const char *filename,const char *magick,
   OSType application)
 {
+  FSSpec
+    file_specification;
+
   OSType
     filetype;
 
   Str255
     name;
-
+   
   assert(filename != (char *) NULL);
-  (void) strcpy((char *) name,filename);
-  c2pstr((char *) name);
   filetype='    ';
   (void) strncpy((char *) &filetype,magick,Min(Extent(magick),4));
-  Create(name,0,application,filetype);
+  (void) strcpy((char *) name,filename);
+  c2pstr((char *) name);
+  FSMakeFSSpec(0,0,name,&file_specification);
+  FSpCreate(&file_specification,application,filetype,smSystemScript);
 }
 
 /*
