@@ -470,6 +470,9 @@ MagickExport unsigned int SignatureImage(Image *image)
   char
     *signature;
 
+  IndexPacket
+    *indexes;
+
   int
     y;
 
@@ -495,7 +498,7 @@ MagickExport unsigned int SignatureImage(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   signature=AllocateString((char *) NULL);
-  message=(unsigned char *) AcquireMemory(8*image->columns);
+  message=(unsigned char *) AcquireMemory(10*image->columns);
   if (message == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitWarning,
       "Unable to compute image signature","Memory allocation failed");
@@ -508,8 +511,9 @@ MagickExport unsigned int SignatureImage(Image *image)
     p=GetImagePixels(image,0,y,image->columns,1);
     if (p == (PixelPacket *) NULL)
       break;
+    indexes=GetIndexes(image);
     q=message;
-    for (x=0; x < image->columns; x++)
+    for (x=0; x < (int) image->columns; x++)
     {
       *q++=XUpScale(p->red) >> 8;
       *q++=XUpScale(p->red);
@@ -517,19 +521,30 @@ MagickExport unsigned int SignatureImage(Image *image)
       *q++=XUpScale(p->green);
       *q++=XUpScale(p->blue) >> 8;
       *q++=XUpScale(p->blue);
-      if (image->matte || (image->colorspace == CMYKColorspace))
+      if (image->colorspace == CMYKColorspace)
         {
           *q++=XUpScale(p->opacity) >> 8;
           *q++=XUpScale(p->opacity);
+          if (image->matte)
+            {
+              *q++=XUpScale(indexes[x]) >> 8;
+              *q++=XUpScale(indexes[x]);
+            }
         }
       else
-        {
-          *q++=XUpScale(MaxRGB) >> 8;
-          *q++=XUpScale(MaxRGB) & 0xff;
-        }
+        if (image->matte)
+          {
+            *q++=XUpScale(p->opacity) >> 8;
+            *q++=XUpScale(p->opacity);
+          }
+        else
+          {
+            *q++=XUpScale(MaxRGB) >> 8;
+            *q++=XUpScale(MaxRGB) & 0xff;
+          }
       p++;
     }
-    UpdateMessageDigest(&message_digest,message,8*image->columns);
+    UpdateMessageDigest(&message_digest,message,q-message);
   }
   /*
     Convert digital signature to a 32 character hex string.
