@@ -59,24 +59,7 @@
 /*
   Typedef declaractions.
 */
-typedef struct _StreamInfo
-{
-  unsigned int
-    columns,
-    rows;
-
-  off_t
-    length;
-
-  void
-    *stash;
-
-  PixelPacket
-    *pixels;
-
-  IndexPacket
-    *indexes;
-} StreamInfo;
+typedef CacheInfo StreamInfo;
 
 /*
   Declare pixel stream interfaces.
@@ -163,7 +146,8 @@ static void DestroyPixelStream(Image *image)
   if (image->cache == (void *) NULL)
     return;
   stream_info=(StreamInfo *) image->cache;
-  LiberateMemory((void **) &stream_info->stash);
+  assert(stream_info->signature == MagickSignature);
+  LiberateMemory((void **) &stream_info->pixels);
   LiberateMemory((void **) &stream_info);
 }
 
@@ -203,6 +187,7 @@ static IndexPacket *GetIndexesFromStream(const Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   stream_info=(StreamInfo *) image->cache;
+  assert(stream_info->signature == MagickSignature);
   return(stream_info->indexes);
 }
 
@@ -329,6 +314,7 @@ static PixelPacket *GetPixelsFromStream(const Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   stream_info=(StreamInfo *) image->cache;
+  assert(stream_info->signature == MagickSignature);
   return(stream_info->pixels);
 }
 
@@ -397,7 +383,8 @@ MagickExport unsigned int ReadStream(const ImageInfo *image_info,
   clone_info->fifo=fifo;
   image=ReadImage(clone_info,exception);
   DestroyImageInfo(clone_info);
-  DestroyImage(image);
+  if (image != (Image *) NULL)
+    DestroyImage(image);
   /*
     Restore pixel cache methods.
   */
@@ -453,45 +440,43 @@ static PixelPacket *SetPixelStream(Image *image,const int x,const int y,
     Validate pixel cache geometry.
   */
   assert(image != (Image *) NULL);
-  if ((x < 0) || (y < 0) || ((x+columns) > (int) image->columns) ||
-      ((y+rows) > (int) image->rows) || (columns == 0) || (rows == 0))
+  if ((x < 0) || (y < 0) || ((x+(int) columns) > (int) image->columns) ||
+      ((y+(int) rows) > (int) image->rows) || (columns == 0) || (rows == 0))
     {
       ThrowException(&image->exception,StreamWarning,
         "Unable to set pixel stream",
         "image does not contain the stream geometry");
       return((PixelPacket *) NULL);
     }
-  if (image->cache == (void *) NULL)
+  stream_info=(StreamInfo *) image->cache;
+  assert(stream_info->signature == MagickSignature);
+  if ((image->storage_class != GetCacheClass(image->cache)) ||
+      (image->colorspace != GetCacheColorspace(image->cache)))
     {
-      stream_info=(StreamInfo *) AcquireMemory(sizeof(StreamInfo));
-      if (stream_info == (StreamInfo *) NULL)
-        MagickError(ResourceLimitError,"Memory allocation failed",
-          "unable to allocate cache info");
+      if (GetCacheClass(image->cache) == UndefinedClass)
+        (void) image->fifo(image,(const void *) NULL,stream_info->columns);
+      stream_info->storage_class=image->storage_class;
+      stream_info->colorspace=image->colorspace;
       stream_info->columns=image->columns;
       stream_info->rows=image->rows;
-      stream_info->stash=(void *) NULL;
-      stream_info->pixels=(PixelPacket *) NULL;
-      stream_info->indexes=(IndexPacket *) NULL;
       image->cache=stream_info;
     }
   /*
     Pixels are stored in a temporary buffer until they are synced to the cache.
   */
-  stream_info=(StreamInfo *) image->cache;
   number_pixels=stream_info->columns*stream_info->rows;
   length=number_pixels*sizeof(PixelPacket);
-  if (image->storage_class == PseudoClass)
+  if ((image->storage_class == PseudoClass) ||
+      (image->colorspace == CMYKColorspace))
     length+=number_pixels*sizeof(IndexPacket);
-  if (stream_info->stash == (void *) NULL)
-    stream_info->stash=AcquireMemory(length);
+  if (stream_info->pixels == (PixelPacket *) NULL)
+    stream_info->pixels=(PixelPacket *) AcquireMemory(length);
   else
-    if (stream_info->length != length)
-      ReacquireMemory((void **) &stream_info->stash,length);
-  if (stream_info->stash == (void *) NULL)
+    if ((stream_info->columns*stream_info->rows) != (columns*rows))
+      ReacquireMemory((void **) &stream_info->pixels,length);
+  if (stream_info->pixels == (void *) NULL)
     MagickError(ResourceLimitError,"Memory allocation failed",
       "unable to allocate cache info");
-  stream_info->length=length;
-  stream_info->pixels=(PixelPacket *) stream_info->stash;
   stream_info->indexes=(IndexPacket *)
     (stream_info->pixels+stream_info->columns*stream_info->rows);
   return(stream_info->pixels);
@@ -532,7 +517,8 @@ static unsigned int SyncPixelStream(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   stream_info=(StreamInfo *) image->cache;
-  return(image->fifo(image,stream_info->pixels,image->columns));
+  assert(stream_info->signature == MagickSignature);
+  return(image->fifo(image,stream_info->pixels,stream_info->columns));
 }
 
 /*
