@@ -256,7 +256,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
     *next;
 
   /*
-    Coalesce the next sequence.
+    Coalesce the image sequence.
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -264,9 +264,9 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
   assert(exception->signature == MagickSignature);
   if (image->next == (Image *) NULL)
     ThrowImageException(OptionWarning,"Unable to coalesce image",
-      "next sequence required");
+      "image sequence required");
   /*
-    Clone first next in sequence.
+    Clone first image in sequence.
   */
   coalesce_image=CloneImage(image,0,0,True,exception);
   if (coalesce_image == (Image *) NULL)
@@ -275,7 +275,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
   /*
     Coalesce image.
   */
-  for (next=image->next; next != (Image *) NULL; next=next->next)
+  for (next=image->next; next != (Image *) NULL; next=GetNextImage(next))
   {
     coalesce_image->next=CloneImage(coalesce_image,0,0,True,exception);
     if (coalesce_image->next == (Image *) NULL)
@@ -284,14 +284,12 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
         return((Image *) NULL);
       }
     coalesce_image->next->previous=coalesce_image;
-    coalesce_image=coalesce_image->next;
+    coalesce_image=GetNextImage(coalesce_image);
     coalesce_image->delay=next->delay;
     coalesce_image->start_loop=next->start_loop;
     CompositeImage(coalesce_image,next->matte ? OverCompositeOp :
       CopyCompositeOp,next,next->page.x,next->page.y);
     GetPageInfo(&coalesce_image->page);
-    CloseImagePixels(next);
-    CloseImagePixels(coalesce_image);
   }
   while (coalesce_image->previous != (Image *) NULL)
     coalesce_image=coalesce_image->previous;
@@ -311,9 +309,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
 %
 %  Method CropImage creates a new image that is a subregion of an existing
 %  one.  It allocates the memory necessary for the new Image structure and
-%  returns a pointer to the new image.  This method is optimized to preserve
-%  the runlength encoding.  That is, the crop image will always use less
-%  memory than the original.
+%  returns a pointer to the new image.
 %
 %  The format of the CropImage method is:
 %
@@ -322,7 +318,7 @@ MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o crop_image: Method CropImage returns a pointer to the crop
+%    o crop_image: Method CropImage returns a pointer to the cropped
 %      image.  A null image is returned if there is a memory shortage or
 %      if the image width or height is zero.
 %
@@ -471,7 +467,7 @@ MagickExport Image *CropImage(Image *image,const RectangleInfo *crop_info,
 %  A description of each parameter follows:
 %
 %    o image: The address of a structure of type Image;  returned from
-%      ReadImage.  It points to the first next in the group to be
+%      ReadImage.  It points to the first image in the group to be
 %      deconstructed.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -529,7 +525,7 @@ MagickExport Image *DeconstructImages(Image *image,ExceptionInfo *exception)
     Compute the bounding box for each next in the sequence.
   */
   i=0;
-  for (next=image->next; next != (Image *) NULL; next=next->next)
+  for (next=image->next; next != (Image *) NULL; next=GetNextImage(next))
   {
     /*
       Set bounding box to the next dimensions.
@@ -603,11 +599,9 @@ MagickExport Image *DeconstructImages(Image *image,ExceptionInfo *exception)
     }
     bounds[i].height=y-bounds[i].y+1;
     i++;
-    CloseImagePixels(next);
-    CloseImagePixels(next->previous);
   }
   /*
-    Clone first next in sequence.
+    Clone first image in sequence.
   */
   deconstruct_image=CloneImage(image,0,0,True,exception);
   if (deconstruct_image == (Image *) NULL)
@@ -616,7 +610,7 @@ MagickExport Image *DeconstructImages(Image *image,ExceptionInfo *exception)
       return((Image *) NULL);
     }
   /*
-    Deconstruct the next sequence.
+    Deconstruct the image sequence.
   */
   i=0;
   for (next=image->next; next != (Image *) NULL; next=next->next)
@@ -639,6 +633,66 @@ MagickExport Image *DeconstructImages(Image *image,ExceptionInfo *exception)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%     F l a t t e n I m a g e                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method FlattenImage merges a sequence of images.  This is useful for
+%  combining Photoshop layers into a single image.
+%
+%  The format of the FlattenImage method is:
+%
+%      Image *FlattenImage(Image *image,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The address of a structure of type Image;  returned from
+%      ReadImage.  It points to the first image in the group to be
+%      coalesced.
+%
+%    o exception: return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *FlattenImages(Image *image,ExceptionInfo *exception)
+{
+  Image
+    *flatten_image;
+
+  register Image
+    *next;
+
+  /*
+    Flatten the image sequence.
+  */
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  if (image->next == (Image *) NULL)
+    ThrowImageException(OptionWarning,"Unable to flatten image",
+      "image sequence required");
+  /*
+    Clone first image in sequence.
+  */
+  flatten_image=CloneImage(image,0,0,True,exception);
+  if (flatten_image == (Image *) NULL)
+    return((Image *) NULL);
+  /*
+    Flatten image.
+  */
+  for (next=image->next; next != (Image *) NULL; next=GetNextImage(next))
+    CompositeImage(flatten_image,next->matte ? OverCompositeOp :
+      CopyCompositeOp,next,next->page.x,next->page.y);
+  (void) IsOpaqueImage(flatten_image);
+  return(flatten_image);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
 %                                                                             %
 %   F l i p I m a g e                                                         %
 %                                                                             %
@@ -836,7 +890,8 @@ MagickExport Image *FlopImage(Image *image,ExceptionInfo *exception)
 %  Method ProfileImage removes or adds a ICM, IPTC, or generic profile to an
 %  image.  If the profile name is specified it is deleted from the image.  If
 %  a filename is specified, one or more profiles are read and added to the
-%  image.
+%  image.  If the profile name is "*" then all profiles are deleted from
+%  the image.
 %
 %  The format of the ProfileImage method is:
 %
@@ -859,6 +914,9 @@ MagickExport Image *FlopImage(Image *image,ExceptionInfo *exception)
 MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
   const char *filename)
 {
+  ExceptionInfo
+    exception;
+
   Image
     *profile_image;
 
@@ -874,9 +932,9 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
   if (filename == (const char *) NULL)
     {
       /*
-        Remove a ICM, IPTC, or generic profile from the image.
+        Remove an ICM, IPTC, or generic profile from the image.
       */
-      if (LocaleCompare("icm",profile_name) == 0)
+      if ((LocaleCompare("icm",profile_name) == 0) || (*profile_name == '*'))
         {
           if (image->color_profile.length != 0)
             LiberateMemory((void **) &image->color_profile.info);
@@ -884,23 +942,24 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
           image->color_profile.info=(unsigned char *) NULL;
         }
       if ((LocaleCompare("8bim",profile_name) == 0) ||
-          (LocaleCompare("iptc",profile_name) == 0))
+          (LocaleCompare("iptc",profile_name) == 0) || (*profile_name == '*'))
         {
           if (image->iptc_profile.length != 0)
             LiberateMemory((void **) &image->iptc_profile.info);
           image->iptc_profile.length=0;
           image->iptc_profile.info=(unsigned char *) NULL;
         }
-      for (i=0; i < image->generic_profiles; i++)
+      for (i=0; i < (int) image->generic_profiles; i++)
       {
-        if (LocaleCompare(image->generic_profile[i].name,profile_name) != 0)
+        if ((LocaleCompare(image->generic_profile[i].name,profile_name) != 0) &&
+            (*profile_name != '*'))
           continue;
         if (image->generic_profile[i].name != (char *) NULL)
           LiberateMemory((void **) &image->generic_profile[i].name);
         if (image->iptc_profile.length != 0)
           LiberateMemory((void **) &image->generic_profile[i].info);
         image->generic_profiles--;
-        for (j=i; j < image->generic_profiles; j++)
+        for (j=i; j < (int) image->generic_profiles; j++)
           image->generic_profile[j]=image->generic_profile[j+1];
         i--;
       }
@@ -911,7 +970,9 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
   */
   image_info=CloneImageInfo((ImageInfo *) NULL);
   (void) strcpy(image_info->filename,filename);
-  profile_image=ReadImage(image_info,&image->exception);
+  profile_image=ReadImage(image_info,&exception);
+  if (exception.severity != UndefinedException)
+    MagickWarning(exception.severity,exception.reason,exception.description);
   DestroyImageInfo(image_info);
   if (profile_image == (Image *) NULL)
     return(False);
@@ -971,6 +1032,16 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
               (transform_profile == (cmsHPROFILE) NULL))
             ThrowBinaryException(ResourceLimitWarning,"Unable to manage color",
               "failed to open color profiles");
+          switch (cmsGetColorSpace(transform_profile))
+          {
+            case icSigCmykData: profile_image->colorspace=CMYKColorspace; break;
+            case icSigYCbCrData:
+              profile_image->colorspace=YCbCrColorspace; break;
+            case icSigLuvData: profile_image->colorspace=YUVColorspace; break;
+            case icSigGrayData: profile_image->colorspace=GRAYColorspace; break;
+            case icSigRgbData: profile_image->colorspace=RGBColorspace; break;
+            default: profile_image->colorspace=RGBColorspace; break;
+          }
           switch (image->rendering_intent)
           {
             case AbsoluteIntent: intent=INTENT_ABSOLUTE_COLORIMETRIC; break;
@@ -980,14 +1051,28 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
             default: intent=INTENT_PERCEPTUAL; break;
           }
           if (image->colorspace == CMYKColorspace)
-            transform=cmsCreateTransform(image_profile,TYPE_CMYK_16,
-              transform_profile,TYPE_CMYK_16,intent,0);
+            {
+              if (profile_image->colorspace == CMYKColorspace)
+                transform=cmsCreateTransform(image_profile,TYPE_CMYK_16,
+                  transform_profile,TYPE_CMYK_16,intent,0);
+              else
+                transform=cmsCreateTransform(image_profile,TYPE_CMYK_16,
+                  transform_profile,TYPE_RGBA_16,intent,0);
+            }
           else
-            transform=cmsCreateTransform(image_profile,TYPE_RGBA_16,
-              transform_profile,TYPE_RGBA_16,intent,0);
+            {
+              if (profile_image->colorspace == CMYKColorspace)
+                transform=cmsCreateTransform(image_profile,TYPE_RGBA_16,
+                  transform_profile,TYPE_CMYK_16,intent,0);
+              else
+                transform=cmsCreateTransform(image_profile,TYPE_RGBA_16,
+                  transform_profile,TYPE_RGBA_16,intent,0);
+            }
           if (transform == (cmsHTRANSFORM) NULL)
             ThrowBinaryException(ResourceLimitWarning,"Unable to manage color",
               "failed to create color transform");
+          if (image->colorspace == CMYKColorspace)
+            image->matte=True;
           for (y=0; y < (int) image->rows; y++)
           {
             q=GetImagePixels(image,0,y,image->columns,1);
@@ -998,7 +1083,7 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
               alpha.red=XUpScale(q->red);
               alpha.green=XUpScale(q->green);
               alpha.blue=XUpScale(q->blue);
-              alpha.opacity=image->matte ? XUpScale(q->opacity) : OpaqueOpacity;
+              alpha.opacity=XUpScale(q->opacity);
               cmsDoTransform(transform,&alpha,&beta,1);
               q->red=XDownScale(beta.red);
               q->green=XDownScale(beta.green);
@@ -1009,6 +1094,9 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
             if (!SyncImagePixels(image))
               break;
           }
+          if (image->colorspace == CMYKColorspace)
+            image->matte=False;
+          image->colorspace=profile_image->colorspace;
           cmsDeleteTransform(transform);
           cmsCloseProfile(image_profile);
           cmsCloseProfile(transform_profile);     
@@ -1040,7 +1128,7 @@ MagickExport unsigned int ProfileImage(Image *image,const char *profile_name,
             (char *) NULL);
         }
       j=image->generic_profiles;
-      for (i=0; i < profile_image->generic_profiles; i++)
+      for (i=0; i < (int) profile_image->generic_profiles; i++)
       {
         image->generic_profile[j].name=profile_image->generic_profile[i].name;
         image->generic_profile[j].length=
@@ -1172,6 +1260,54 @@ MagickExport Image *RollImage(Image *image,const int x_offset,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S h a v e I m a g e                                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  Method ShaveImage shaves pixels from the image edges.  It allocates the
+%  memory necessary for the new Image structure and returns a pointer to the
+%  new image.
+%
+%  The format of the ShaveImage method is:
+%
+%      Image *ShaveImage(Image *image,const RectangleInfo *shave_info,
+%        ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o shave_image: Method ShaveImage returns a pointer to the shaved
+%      image.  A null image is returned if there is a memory shortage or
+%      if the image width or height is zero.
+%
+%    o image: The address of a structure of type Image.
+%
+%    o shave_info: Specifies a pointer to a RectangleInfo which defines the
+%      region of the image to crop.
+%
+%    o exception: return any errors or warnings in this structure.
+%
+%
+*/
+MagickExport Image *ShaveImage(Image *image,const RectangleInfo *shave_info,
+  ExceptionInfo *exception)
+{
+  RectangleInfo
+    crop_info;
+
+  crop_info.width=image->columns-2*shave_info->width;
+  crop_info.height=image->rows-2*shave_info->height;
+  crop_info.x=shave_info->width;
+  crop_info.y=shave_info->height;
+  return(CropImage(image,&crop_info,exception));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   T r a n s f o r m I m a g e                                               %
 %                                                                             %
 %                                                                             %
@@ -1281,6 +1417,7 @@ MagickExport void TransformImage(Image **image,const char *crop_geometry,
             /*
               Crop repeatedly to create uniform subimages.
             */
+            next_image=(Image *) NULL;
             for (y=0; y < (int) transform_image->rows; y+=height)
             {
               for (x=0; x < (int) transform_image->columns; x+=width)
